Class: Zippendo::BatchSendShipments200ResponseSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::BatchSendShipments200ResponseSummary
- Defined in:
- lib/zippendo/models/batch_send_shipments200_response_summary.rb
Overview
Aggregate counts for the batch.
Instance Attribute Summary collapse
-
#failed ⇒ Object
How many the carrier or Zippendo rejected.
-
#sent ⇒ Object
How many were successfully booked.
-
#skipped ⇒ Object
How many the batch ran out of time to attempt.
-
#total ⇒ Object
Number of unique shipments requested.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BatchSendShipments200ResponseSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BatchSendShipments200ResponseSummary
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::BatchSendShipments200ResponseSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::BatchSendShipments200ResponseSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total') self.total = attributes[:'total'] else self.total = nil end if attributes.key?(:'sent') self.sent = attributes[:'sent'] else self.sent = nil end if attributes.key?(:'failed') self.failed = attributes[:'failed'] else self.failed = nil end if attributes.key?(:'skipped') self.skipped = attributes[:'skipped'] else self.skipped = nil end end |
Instance Attribute Details
#failed ⇒ Object
How many the carrier or Zippendo rejected.
26 27 28 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 26 def failed @failed end |
#sent ⇒ Object
How many were successfully booked.
23 24 25 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 23 def sent @sent end |
#skipped ⇒ Object
How many the batch ran out of time to attempt. Submit these again.
29 30 31 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 29 def skipped @skipped end |
#total ⇒ Object
Number of unique shipments requested.
20 21 22 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 20 def total @total end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 32 def self.attribute_map { :'total' => :'total', :'sent' => :'sent', :'failed' => :'failed', :'skipped' => :'skipped' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 52 def self.openapi_types { :'total' => :'Integer', :'sent' => :'Integer', :'failed' => :'Integer', :'skipped' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && total == o.total && sent == o.sent && failed == o.failed && skipped == o.skipped end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 274 def hash [total, sent, failed, skipped].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @total.nil? invalid_properties.push('invalid value for "total", total cannot be nil.') end if @total > 9007199254740991 invalid_properties.push('invalid value for "total", must be smaller than or equal to 9007199254740991.') end if @total < -9007199254740991 invalid_properties.push('invalid value for "total", must be greater than or equal to -9007199254740991.') end if @sent.nil? invalid_properties.push('invalid value for "sent", sent cannot be nil.') end if @sent > 9007199254740991 invalid_properties.push('invalid value for "sent", must be smaller than or equal to 9007199254740991.') end if @sent < -9007199254740991 invalid_properties.push('invalid value for "sent", must be greater than or equal to -9007199254740991.') end if @failed.nil? invalid_properties.push('invalid value for "failed", failed cannot be nil.') end if @failed > 9007199254740991 invalid_properties.push('invalid value for "failed", must be smaller than or equal to 9007199254740991.') end if @failed < -9007199254740991 invalid_properties.push('invalid value for "failed", must be greater than or equal to -9007199254740991.') end if @skipped.nil? invalid_properties.push('invalid value for "skipped", skipped cannot be nil.') end if @skipped > 9007199254740991 invalid_properties.push('invalid value for "skipped", must be smaller than or equal to 9007199254740991.') end if @skipped < -9007199254740991 invalid_properties.push('invalid value for "skipped", must be greater than or equal to -9007199254740991.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @total.nil? return false if @total > 9007199254740991 return false if @total < -9007199254740991 return false if @sent.nil? return false if @sent > 9007199254740991 return false if @sent < -9007199254740991 return false if @failed.nil? return false if @failed > 9007199254740991 return false if @failed < -9007199254740991 return false if @skipped.nil? return false if @skipped > 9007199254740991 return false if @skipped < -9007199254740991 true end |