Class: Zippendo::CarriersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zippendo/api/carriers_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CarriersApi

Returns a new instance of CarriersApi.



19
20
21
# File 'lib/zippendo/api/carriers_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zippendo/api/carriers_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#connect_carrier(org_id, connect_carrier_request, opts = {}) ⇒ ListCarriers200ResponseDataInner

Connect carrier Connects a new carrier to the organization with its configuration.

Parameters:

  • org_id (String)

    Organization ID

  • connect_carrier_request (ConnectCarrierRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/zippendo/api/carriers_api.rb', line 28

def connect_carrier(org_id, connect_carrier_request, opts = {})
  data, _status_code, _headers = connect_carrier_with_http_info(org_id, connect_carrier_request, opts)
  data
end

#connect_carrier_with_http_info(org_id, connect_carrier_request, opts = {}) ⇒ Array<(ListCarriers200ResponseDataInner, Integer, Hash)>

Connect carrier Connects a new carrier to the organization with its configuration.

Parameters:

  • org_id (String)

    Organization ID

  • connect_carrier_request (ConnectCarrierRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zippendo/api/carriers_api.rb', line 39

def connect_carrier_with_http_info(org_id, connect_carrier_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.connect_carrier ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.connect_carrier"
  end
  # verify the required parameter 'connect_carrier_request' is set
  if @api_client.config.client_side_validation && connect_carrier_request.nil?
    fail ArgumentError, "Missing the required parameter 'connect_carrier_request' when calling CarriersApi.connect_carrier"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers'.sub('{orgId}', CGI.escape(org_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(connect_carrier_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ListCarriers200ResponseDataInner'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.connect_carrier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#connect_carrier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#disconnect_carrier(org_id, carrier_id, opts = {}) ⇒ String

Disconnect carrier Disconnects a carrier from the organization.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


102
103
104
105
# File 'lib/zippendo/api/carriers_api.rb', line 102

def disconnect_carrier(org_id, carrier_id, opts = {})
  data, _status_code, _headers = disconnect_carrier_with_http_info(org_id, carrier_id, opts)
  data
end

#disconnect_carrier_with_http_info(org_id, carrier_id, opts = {}) ⇒ Array<(String, Integer, Hash)>

Disconnect carrier Disconnects a carrier from the organization.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Integer, Hash)>)

    String data, response status code and response headers



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zippendo/api/carriers_api.rb', line 113

def disconnect_carrier_with_http_info(org_id, carrier_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.disconnect_carrier ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.disconnect_carrier"
  end
  # verify the required parameter 'carrier_id' is set
  if @api_client.config.client_side_validation && carrier_id.nil?
    fail ArgumentError, "Missing the required parameter 'carrier_id' when calling CarriersApi.disconnect_carrier"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers/{carrierId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{carrierId}', CGI.escape(carrier_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'String'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.disconnect_carrier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#disconnect_carrier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_carrier(org_id, carrier_id, opts = {}) ⇒ ListCarriers200ResponseDataInner

Get carrier Returns a single connected carrier.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



171
172
173
174
# File 'lib/zippendo/api/carriers_api.rb', line 171

def get_carrier(org_id, carrier_id, opts = {})
  data, _status_code, _headers = get_carrier_with_http_info(org_id, carrier_id, opts)
  data
end

#get_carrier_with_http_info(org_id, carrier_id, opts = {}) ⇒ Array<(ListCarriers200ResponseDataInner, Integer, Hash)>

Get carrier Returns a single connected carrier.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zippendo/api/carriers_api.rb', line 182

def get_carrier_with_http_info(org_id, carrier_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.get_carrier ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.get_carrier"
  end
  # verify the required parameter 'carrier_id' is set
  if @api_client.config.client_side_validation && carrier_id.nil?
    fail ArgumentError, "Missing the required parameter 'carrier_id' when calling CarriersApi.get_carrier"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers/{carrierId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{carrierId}', CGI.escape(carrier_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListCarriers200ResponseDataInner'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.get_carrier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#get_carrier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_carrier_product_service_points(org_id, carrier_id, product_id, list_carrier_product_service_points_request, opts = {}) ⇒ Array<ListCarrierProductServicePoints200ResponseInner>

List product service points Returns pickup service points near a location for a specific carrier product.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • product_id (String)

    Carrier product ID

  • list_carrier_product_service_points_request (ListCarrierProductServicePointsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



242
243
244
245
# File 'lib/zippendo/api/carriers_api.rb', line 242

def list_carrier_product_service_points(org_id, carrier_id, product_id, list_carrier_product_service_points_request, opts = {})
  data, _status_code, _headers = list_carrier_product_service_points_with_http_info(org_id, carrier_id, product_id, list_carrier_product_service_points_request, opts)
  data
end

#list_carrier_product_service_points_with_http_info(org_id, carrier_id, product_id, list_carrier_product_service_points_request, opts = {}) ⇒ Array<(Array<ListCarrierProductServicePoints200ResponseInner>, Integer, Hash)>

List product service points Returns pickup service points near a location for a specific carrier product.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • product_id (String)

    Carrier product ID

  • list_carrier_product_service_points_request (ListCarrierProductServicePointsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/zippendo/api/carriers_api.rb', line 255

def list_carrier_product_service_points_with_http_info(org_id, carrier_id, product_id, list_carrier_product_service_points_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.list_carrier_product_service_points ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.list_carrier_product_service_points"
  end
  # verify the required parameter 'carrier_id' is set
  if @api_client.config.client_side_validation && carrier_id.nil?
    fail ArgumentError, "Missing the required parameter 'carrier_id' when calling CarriersApi.list_carrier_product_service_points"
  end
  # verify the required parameter 'product_id' is set
  if @api_client.config.client_side_validation && product_id.nil?
    fail ArgumentError, "Missing the required parameter 'product_id' when calling CarriersApi.list_carrier_product_service_points"
  end
  # verify the required parameter 'list_carrier_product_service_points_request' is set
  if @api_client.config.client_side_validation && list_carrier_product_service_points_request.nil?
    fail ArgumentError, "Missing the required parameter 'list_carrier_product_service_points_request' when calling CarriersApi.list_carrier_product_service_points"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers/{carrierId}/products/{productId}/service-points'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{carrierId}', CGI.escape(carrier_id.to_s)).sub('{productId}', CGI.escape(product_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(list_carrier_product_service_points_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ListCarrierProductServicePoints200ResponseInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.list_carrier_product_service_points",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#list_carrier_product_service_points\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_carrier_products(org_id, carrier_id, opts = {}) ⇒ Array<ListCarrierProducts200ResponseInner>

List carrier products Returns the shipping products available for a connected carrier.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



326
327
328
329
# File 'lib/zippendo/api/carriers_api.rb', line 326

def list_carrier_products(org_id, carrier_id, opts = {})
  data, _status_code, _headers = list_carrier_products_with_http_info(org_id, carrier_id, opts)
  data
end

#list_carrier_products_with_http_info(org_id, carrier_id, opts = {}) ⇒ Array<(Array<ListCarrierProducts200ResponseInner>, Integer, Hash)>

List carrier products Returns the shipping products available for a connected carrier.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/zippendo/api/carriers_api.rb', line 337

def list_carrier_products_with_http_info(org_id, carrier_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.list_carrier_products ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.list_carrier_products"
  end
  # verify the required parameter 'carrier_id' is set
  if @api_client.config.client_side_validation && carrier_id.nil?
    fail ArgumentError, "Missing the required parameter 'carrier_id' when calling CarriersApi.list_carrier_products"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers/{carrierId}/products'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{carrierId}', CGI.escape(carrier_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ListCarrierProducts200ResponseInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.list_carrier_products",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#list_carrier_products\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_carriers(org_id, opts = {}) ⇒ ListCarriers200Response

List carriers Returns a paginated list of carriers connected to the organization.

Parameters:

  • org_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Items per page (max 100) (default to 20)

Returns:



396
397
398
399
# File 'lib/zippendo/api/carriers_api.rb', line 396

def list_carriers(org_id, opts = {})
  data, _status_code, _headers = list_carriers_with_http_info(org_id, opts)
  data
end

#list_carriers_with_http_info(org_id, opts = {}) ⇒ Array<(ListCarriers200Response, Integer, Hash)>

List carriers Returns a paginated list of carriers connected to the organization.

Parameters:

  • org_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Items per page (max 100) (default to 20)

Returns:

  • (Array<(ListCarriers200Response, Integer, Hash)>)

    ListCarriers200Response data, response status code and response headers



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/zippendo/api/carriers_api.rb', line 408

def list_carriers_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.list_carriers ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.list_carriers"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CarriersApi.list_carriers, must be smaller than or equal to 9007199254740991.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CarriersApi.list_carriers, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CarriersApi.list_carriers, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CarriersApi.list_carriers, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/orgs/{orgId}/carriers'.sub('{orgId}', CGI.escape(org_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListCarriers200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.list_carriers",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#list_carriers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_carrier(org_id, carrier_id, update_carrier_request, opts = {}) ⇒ ListCarriers200ResponseDataInner

Update carrier Updates a connected carrier's configuration or name.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • update_carrier_request (UpdateCarrierRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



481
482
483
484
# File 'lib/zippendo/api/carriers_api.rb', line 481

def update_carrier(org_id, carrier_id, update_carrier_request, opts = {})
  data, _status_code, _headers = update_carrier_with_http_info(org_id, carrier_id, update_carrier_request, opts)
  data
end

#update_carrier_with_http_info(org_id, carrier_id, update_carrier_request, opts = {}) ⇒ Array<(ListCarriers200ResponseDataInner, Integer, Hash)>

Update carrier Updates a connected carrier's configuration or name.

Parameters:

  • org_id (String)

    Organization ID

  • carrier_id (String)

    Carrier ID

  • update_carrier_request (UpdateCarrierRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/zippendo/api/carriers_api.rb', line 493

def update_carrier_with_http_info(org_id, carrier_id, update_carrier_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CarriersApi.update_carrier ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CarriersApi.update_carrier"
  end
  # verify the required parameter 'carrier_id' is set
  if @api_client.config.client_side_validation && carrier_id.nil?
    fail ArgumentError, "Missing the required parameter 'carrier_id' when calling CarriersApi.update_carrier"
  end
  # verify the required parameter 'update_carrier_request' is set
  if @api_client.config.client_side_validation && update_carrier_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_carrier_request' when calling CarriersApi.update_carrier"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/carriers/{carrierId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{carrierId}', CGI.escape(carrier_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_carrier_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ListCarriers200ResponseDataInner'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"CarriersApi.update_carrier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CarriersApi#update_carrier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end