Class: Zippendo::CreateApiToken201Response

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/create_api_token201_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateApiToken201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/zippendo/models/create_api_token201_response.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateApiToken201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateApiToken201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'token_prefix')
    self.token_prefix = attributes[:'token_prefix']
  else
    self.token_prefix = nil
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  else
    self.scopes = nil
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  else
    self.brand_id = nil
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  else
    self.last_used_at = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end
end

Instance Attribute Details

#brand_idObject

Brand this token is restricted to, or null for organization-wide access



31
32
33
# File 'lib/zippendo/models/create_api_token201_response.rb', line 31

def brand_id
  @brand_id
end

#created_atObject

Creation timestamp (ISO 8601)



40
41
42
# File 'lib/zippendo/models/create_api_token201_response.rb', line 40

def created_at
  @created_at
end

#expires_atObject

Expiry timestamp (ISO 8601), null if it never expires



37
38
39
# File 'lib/zippendo/models/create_api_token201_response.rb', line 37

def expires_at
  @expires_at
end

#idObject

Unique API token identifier



19
20
21
# File 'lib/zippendo/models/create_api_token201_response.rb', line 19

def id
  @id
end

#last_used_atObject

Timestamp the token was last used (ISO 8601), null if never used



34
35
36
# File 'lib/zippendo/models/create_api_token201_response.rb', line 34

def last_used_at
  @last_used_at
end

#nameObject

Token name for identification



22
23
24
# File 'lib/zippendo/models/create_api_token201_response.rb', line 22

def name
  @name
end

#scopesObject

Permission scopes granted by the token



28
29
30
# File 'lib/zippendo/models/create_api_token201_response.rb', line 28

def scopes
  @scopes
end

#tokenObject

Full API token (only shown once)



43
44
45
# File 'lib/zippendo/models/create_api_token201_response.rb', line 43

def token
  @token
end

#token_prefixObject

First 12 chars of the token for identification



25
26
27
# File 'lib/zippendo/models/create_api_token201_response.rb', line 25

def token_prefix
  @token_prefix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/zippendo/models/create_api_token201_response.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/zippendo/models/create_api_token201_response.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/zippendo/models/create_api_token201_response.rb', line 46

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'token_prefix' => :'tokenPrefix',
    :'scopes' => :'scopes',
    :'brand_id' => :'brandId',
    :'last_used_at' => :'lastUsedAt',
    :'expires_at' => :'expiresAt',
    :'created_at' => :'createdAt',
    :'token' => :'token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/zippendo/models/create_api_token201_response.rb', line 303

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
91
92
# File 'lib/zippendo/models/create_api_token201_response.rb', line 86

def self.openapi_nullable
  Set.new([
    :'brand_id',
    :'last_used_at',
    :'expires_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zippendo/models/create_api_token201_response.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'token_prefix' => :'String',
    :'scopes' => :'Array<String>',
    :'brand_id' => :'String',
    :'last_used_at' => :'String',
    :'expires_at' => :'String',
    :'created_at' => :'String',
    :'token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/zippendo/models/create_api_token201_response.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      token_prefix == o.token_prefix &&
      scopes == o.scopes &&
      brand_id == o.brand_id &&
      last_used_at == o.last_used_at &&
      expires_at == o.expires_at &&
      created_at == o.created_at &&
      token == o.token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


290
291
292
# File 'lib/zippendo/models/create_api_token201_response.rb', line 290

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



296
297
298
# File 'lib/zippendo/models/create_api_token201_response.rb', line 296

def hash
  [id, name, token_prefix, scopes, brand_id, last_used_at, expires_at, created_at, token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zippendo/models/create_api_token201_response.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @token_prefix.nil?
    invalid_properties.push('invalid value for "token_prefix", token_prefix cannot be nil.')
  end

  if @scopes.nil?
    invalid_properties.push('invalid value for "scopes", scopes cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/zippendo/models/create_api_token201_response.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
# File 'lib/zippendo/models/create_api_token201_response.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @token_prefix.nil?
  return false if @scopes.nil?
  return false if @created_at.nil?
  return false if @token.nil?
  true
end