Class: Zippendo::CreateApiTokenRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/create_api_token_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateApiTokenRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zippendo/models/create_api_token_request.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateApiTokenRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateApiTokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  else
    self.scopes = nil
  end

  if attributes.key?(:'expires_in_days')
    self.expires_in_days = attributes[:'expires_in_days']
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  end
end

Instance Attribute Details

#brand_idObject

Restrict this token to a single brand. Requests made with it can only read and write that brand's data. Omit for organization-wide access.



28
29
30
# File 'lib/zippendo/models/create_api_token_request.rb', line 28

def brand_id
  @brand_id
end

#expires_in_daysObject

Token expiry in days (optional, max 365)



25
26
27
# File 'lib/zippendo/models/create_api_token_request.rb', line 25

def expires_in_days
  @expires_in_days
end

#nameObject

Token name for identification



19
20
21
# File 'lib/zippendo/models/create_api_token_request.rb', line 19

def name
  @name
end

#scopesObject

Permission scopes for the token



22
23
24
# File 'lib/zippendo/models/create_api_token_request.rb', line 22

def scopes
  @scopes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/zippendo/models/create_api_token_request.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/zippendo/models/create_api_token_request.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/zippendo/models/create_api_token_request.rb', line 53

def self.attribute_map
  {
    :'name' => :'name',
    :'scopes' => :'scopes',
    :'expires_in_days' => :'expiresInDays',
    :'brand_id' => :'brandId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/zippendo/models/create_api_token_request.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
87
# File 'lib/zippendo/models/create_api_token_request.rb', line 83

def self.openapi_nullable
  Set.new([
    :'brand_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/zippendo/models/create_api_token_request.rb', line 73

def self.openapi_types
  {
    :'name' => :'String',
    :'scopes' => :'Array<String>',
    :'expires_in_days' => :'Integer',
    :'brand_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



216
217
218
219
220
221
222
223
# File 'lib/zippendo/models/create_api_token_request.rb', line 216

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      scopes == o.scopes &&
      expires_in_days == o.expires_in_days &&
      brand_id == o.brand_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/zippendo/models/create_api_token_request.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/zippendo/models/create_api_token_request.rb', line 233

def hash
  [name, scopes, expires_in_days, brand_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/zippendo/models/create_api_token_request.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @scopes.nil?
    invalid_properties.push('invalid value for "scopes", scopes cannot be nil.')
  end

  if @scopes.length < 1
    invalid_properties.push('invalid value for "scopes", number of items must be greater than or equal to 1.')
  end

  if !@expires_in_days.nil? && @expires_in_days > 365
    invalid_properties.push('invalid value for "expires_in_days", must be smaller than or equal to 365.')
  end

  if !@expires_in_days.nil? && @expires_in_days < 1
    invalid_properties.push('invalid value for "expires_in_days", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/zippendo/models/create_api_token_request.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zippendo/models/create_api_token_request.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @name.to_s.length < 1
  return false if @scopes.nil?
  return false if @scopes.length < 1
  return false if !@expires_in_days.nil? && @expires_in_days > 365
  return false if !@expires_in_days.nil? && @expires_in_days < 1
  true
end