Class: Zippendo::CreateOrgWebhook201Response

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/create_org_webhook201_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateOrgWebhook201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateOrgWebhook201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateOrgWebhook201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  else
    self.secret = nil
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  else
    self.events = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  else
    self.brand_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#brand_idObject

Brand this record belongs to, or null when it is organization-wide



37
38
39
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 37

def brand_id
  @brand_id
end

#created_atObject

Creation timestamp (ISO 8601)



40
41
42
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 40

def created_at
  @created_at
end

#eventsObject

Events the webhook is subscribed to



31
32
33
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 31

def events
  @events
end

#idObject

Webhook ID



19
20
21
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 19

def id
  @id
end

#is_activeObject

Whether the webhook is active



34
35
36
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 34

def is_active
  @is_active
end

#nameObject

Human-readable webhook name



22
23
24
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 22

def name
  @name
end

#secretObject

Signing secret used to verify webhook payloads



28
29
30
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 28

def secret
  @secret
end

#updated_atObject

Last update timestamp (ISO 8601)



43
44
45
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 43

def updated_at
  @updated_at
end

#urlObject

Webhook endpoint URL



25
26
27
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 25

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 46

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'url' => :'url',
    :'secret' => :'secret',
    :'events' => :'events',
    :'is_active' => :'isActive',
    :'brand_id' => :'brandId',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 86

def self.openapi_nullable
  Set.new([
    :'brand_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'url' => :'String',
    :'secret' => :'String',
    :'events' => :'Array<String>',
    :'is_active' => :'Boolean',
    :'brand_id' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      url == o.url &&
      secret == o.secret &&
      events == o.events &&
      is_active == o.is_active &&
      brand_id == o.brand_id &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 324

def hash
  [id, name, url, secret, events, is_active, brand_id, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @secret.nil?
    invalid_properties.push('invalid value for "secret", secret cannot be nil.')
  end

  if @events.nil?
    invalid_properties.push('invalid value for "events", events cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zippendo/models/create_org_webhook201_response.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @url.nil?
  return false if @secret.nil?
  return false if @events.nil?
  return false if @is_active.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end