Class: Zippendo::CreateShipment201ResponseDocumentsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/create_shipment201_response_documents_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateShipment201ResponseDocumentsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShipment201ResponseDocumentsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShipment201ResponseDocumentsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'shipment_id')
    self.shipment_id = attributes[:'shipment_id']
  else
    self.shipment_id = nil
  end

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  else
    self.document_type = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  else
    self.content = nil
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = 'A4'
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#contentObject

Base64-encoded document/label content.



31
32
33
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 31

def content
  @content
end

#created_atObject

Timestamp when the document was created.



37
38
39
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 37

def created_at
  @created_at
end

#document_typeObject

Type of shipment document.



25
26
27
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 25

def document_type
  @document_type
end

#formatObject

File format of the document content.



28
29
30
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 28

def format
  @format
end

#idObject

Unique document identifier.



19
20
21
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 19

def id
  @id
end

#shipment_idObject

Identifier of the shipment this document belongs to.



22
23
24
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 22

def shipment_id
  @shipment_id
end

#sizeObject

Physical print size of the document.



34
35
36
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 34

def size
  @size
end

#updated_atObject

Timestamp when the document was last updated.



40
41
42
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'shipment_id' => :'shipmentId',
    :'document_type' => :'documentType',
    :'format' => :'format',
    :'content' => :'content',
    :'size' => :'size',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 344

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'shipment_id' => :'String',
    :'document_type' => :'String',
    :'format' => :'String',
    :'content' => :'String',
    :'size' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      shipment_id == o.shipment_id &&
      document_type == o.document_type &&
      format == o.format &&
      content == o.content &&
      size == o.size &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


331
332
333
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 331

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



337
338
339
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 337

def hash
  [id, shipment_id, document_type, format, content, size, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @shipment_id.nil?
    invalid_properties.push('invalid value for "shipment_id", shipment_id cannot be nil.')
  end

  if @document_type.nil?
    invalid_properties.push('invalid value for "document_type", document_type cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @content.nil?
    invalid_properties.push('invalid value for "content", content cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zippendo/models/create_shipment201_response_documents_inner.rb', line 215

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @shipment_id.nil?
  return false if @document_type.nil?
  document_type_validator = EnumAttributeValidator.new('String', ["label", "customs_invoice", "commercial_invoice", "proforma_invoice", "packing_list", "certificate_of_origin", "cn22", "cn23", "other"])
  return false unless document_type_validator.valid?(@document_type)
  return false if @format.nil?
  format_validator = EnumAttributeValidator.new('String', ["pdf", "png", "jpg", "zpl", "svg"])
  return false unless format_validator.valid?(@format)
  return false if @content.nil?
  return false if @size.nil?
  size_validator = EnumAttributeValidator.new('String', ["100X150", "100X192", "A4", "100x100"])
  return false unless size_validator.valid?(@size)
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end