Class: Zippendo::CreateShipment201ResponseLogsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateShipment201ResponseLogsInner
- Defined in:
- lib/zippendo/models/create_shipment201_response_logs_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Timestamp when the log entry was created.
-
#direction ⇒ Object
Direction of the logged request.
-
#duration ⇒ Object
Request duration in milliseconds.
-
#error ⇒ Object
Error message if the request failed.
-
#id ⇒ Object
Unique log entry identifier.
-
#request ⇒ Object
Captured request payload.
-
#response ⇒ Object
Captured response payload.
-
#status_code ⇒ Object
HTTP status code of the response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateShipment201ResponseLogsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateShipment201ResponseLogsInner
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShipment201ResponseLogsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShipment201ResponseLogsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = nil end if attributes.key?(:'request') self.request = attributes[:'request'] else self.request = nil end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Timestamp when the log entry was created.
40 41 42 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 40 def created_at @created_at end |
#direction ⇒ Object
Direction of the logged request.
22 23 24 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 22 def direction @direction end |
#duration ⇒ Object
Request duration in milliseconds.
37 38 39 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 37 def duration @duration end |
#error ⇒ Object
Error message if the request failed.
34 35 36 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 34 def error @error end |
#id ⇒ Object
Unique log entry identifier.
19 20 21 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 19 def id @id end |
#request ⇒ Object
Captured request payload.
25 26 27 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 25 def request @request end |
#response ⇒ Object
Captured response payload.
28 29 30 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 28 def response @response end |
#status_code ⇒ Object
HTTP status code of the response.
31 32 33 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 31 def status_code @status_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 65 def self.attribute_map { :'id' => :'id', :'direction' => :'direction', :'request' => :'request', :'response' => :'response', :'status_code' => :'statusCode', :'error' => :'error', :'duration' => :'duration', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 109 110 111 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 103 def self.openapi_nullable Set.new([ :'request', :'response', :'status_code', :'error', :'duration', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 89 def self.openapi_types { :'id' => :'String', :'direction' => :'String', :'request' => :'Object', :'response' => :'Object', :'status_code' => :'Float', :'error' => :'String', :'duration' => :'Float', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && direction == o.direction && request == o.request && response == o.response && status_code == o.status_code && error == o.error && duration == o.duration && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 255 def hash [id, direction, request, response, status_code, error, duration, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @direction.nil? invalid_properties.push('invalid value for "direction", direction cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 |
# File 'lib/zippendo/models/create_shipment201_response_logs_inner.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @direction.nil? direction_validator = EnumAttributeValidator.new('String', ["inbound", "outbound", "carrier"]) return false unless direction_validator.valid?(@direction) return false if @created_at.nil? true end |