Class: Zippendo::CreateShipmentRequestPartiesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateShipmentRequestPartiesInner
- Defined in:
- lib/zippendo/models/create_shipment_request_parties_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address1 ⇒ Object
Primary street address line.
-
#address2 ⇒ Object
Secondary address line.
-
#attention ⇒ Object
Attention contact at the party.
-
#attributes ⇒ Object
Additional carrier-specific attributes for the party.
-
#city ⇒ Object
City of the party address.
-
#country_code ⇒ Object
ISO 3166-1 alpha-2 country code.
-
#email ⇒ Object
Email address of the party.
-
#name ⇒ Object
Full name or company name of the party.
-
#phone ⇒ Object
Phone number of the party in E.164 format.
-
#postal_code ⇒ Object
Postal code of the party address.
-
#type ⇒ Object
Role of the party in the shipment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateShipmentRequestPartiesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateShipmentRequestPartiesInner
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShipmentRequestPartiesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShipmentRequestPartiesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'attention') self.attention = attributes[:'attention'] end if attributes.key?(:'address1') self.address1 = attributes[:'address1'] else self.address1 = nil end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] else self.postal_code = nil end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] else self.country_code = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Array) self.attributes = value end end end |
Instance Attribute Details
#address1 ⇒ Object
Primary street address line.
28 29 30 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 28 def address1 @address1 end |
#address2 ⇒ Object
Secondary address line.
31 32 33 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 31 def address2 @address2 end |
#attention ⇒ Object
Attention contact at the party.
25 26 27 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 25 def attention @attention end |
#attributes ⇒ Object
Additional carrier-specific attributes for the party.
49 50 51 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 49 def attributes @attributes end |
#city ⇒ Object
City of the party address.
37 38 39 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 37 def city @city end |
#country_code ⇒ Object
ISO 3166-1 alpha-2 country code.
40 41 42 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 40 def country_code @country_code end |
#email ⇒ Object
Email address of the party.
43 44 45 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 43 def email @email end |
#name ⇒ Object
Full name or company name of the party.
22 23 24 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 22 def name @name end |
#phone ⇒ Object
Phone number of the party in E.164 format.
46 47 48 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 46 def phone @phone end |
#postal_code ⇒ Object
Postal code of the party address.
34 35 36 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 34 def postal_code @postal_code end |
#type ⇒ Object
Role of the party in the shipment.
19 20 21 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 19 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 74 def self.attribute_map { :'type' => :'type', :'name' => :'name', :'attention' => :'attention', :'address1' => :'address1', :'address2' => :'address2', :'postal_code' => :'postalCode', :'city' => :'city', :'country_code' => :'countryCode', :'email' => :'email', :'phone' => :'phone', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 413 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 122 123 124 125 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 118 def self.openapi_nullable Set.new([ :'attention', :'address2', :'email', :'phone', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 101 def self.openapi_types { :'type' => :'String', :'name' => :'String', :'attention' => :'String', :'address1' => :'String', :'address2' => :'String', :'postal_code' => :'String', :'city' => :'String', :'country_code' => :'String', :'email' => :'String', :'phone' => :'String', :'attributes' => :'Array<CreateShipmentRequestPartiesInnerAttributesInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 382 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && name == o.name && attention == o.attention && address1 == o.address1 && address2 == o.address2 && postal_code == o.postal_code && city == o.city && country_code == o.country_code && email == o.email && phone == o.phone && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
400 401 402 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 400 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
406 407 408 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 406 def hash [type, name, attention, address1, address2, postal_code, city, country_code, email, phone, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 204 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @address1.nil? invalid_properties.push('invalid value for "address1", address1 cannot be nil.') end if @address1.to_s.length < 1 invalid_properties.push('invalid value for "address1", the character length must be greater than or equal to 1.') end if @postal_code.nil? invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.') end if @postal_code.to_s.length < 1 invalid_properties.push('invalid value for "postal_code", the character length must be greater than or equal to 1.') end if @city.nil? invalid_properties.push('invalid value for "city", city cannot be nil.') end if @city.to_s.length < 1 invalid_properties.push('invalid value for "city", the character length must be greater than or equal to 1.') end if @country_code.nil? invalid_properties.push('invalid value for "country_code", country_code cannot be nil.') end if @country_code.to_s.length > 2 invalid_properties.push('invalid value for "country_code", the character length must be smaller than or equal to 2.') end if @country_code.to_s.length < 2 invalid_properties.push('invalid value for "country_code", the character length must be greater than or equal to 2.') end pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) if !@email.nil? && @email !~ pattern invalid_properties.push("invalid value for \"email\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 435 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/zippendo/models/create_shipment_request_parties_inner.rb', line 265 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["sender", "receiver", "pickup", "billing", "freight_payer", "service_point", "return"]) return false unless type_validator.valid?(@type) return false if @name.nil? return false if @name.to_s.length < 1 return false if @address1.nil? return false if @address1.to_s.length < 1 return false if @postal_code.nil? return false if @postal_code.to_s.length < 1 return false if @city.nil? return false if @city.to_s.length < 1 return false if @country_code.nil? return false if @country_code.to_s.length > 2 return false if @country_code.to_s.length < 2 return false if !@email.nil? && @email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) true end |