Class: Zippendo::CreateShippingQuote200ResponseRatesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateShippingQuote200ResponseRatesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShippingQuote200ResponseRatesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShippingQuote200ResponseRatesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'service_name')
    self.service_name = attributes[:'service_name']
  else
    self.service_name = nil
  end

  if attributes.key?(:'service_code')
    self.service_code = attributes[:'service_code']
  else
    self.service_code = nil
  end

  if attributes.key?(:'total_price')
    self.total_price = attributes[:'total_price']
  else
    self.total_price = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'min_delivery_date')
    self.min_delivery_date = attributes[:'min_delivery_date']
  end

  if attributes.key?(:'max_delivery_date')
    self.max_delivery_date = attributes[:'max_delivery_date']
  end

  if attributes.key?(:'carrier_name')
    self.carrier_name = attributes[:'carrier_name']
  end

  if attributes.key?(:'carrier_slug')
    self.carrier_slug = attributes[:'carrier_slug']
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  end

  if attributes.key?(:'shipping_rule_id')
    self.shipping_rule_id = attributes[:'shipping_rule_id']
  else
    self.shipping_rule_id = nil
  end
end

Instance Attribute Details

#carrier_nameObject

Carrier display name



40
41
42
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 40

def carrier_name
  @carrier_name
end

#carrier_slugObject

Carrier slug identifier



43
44
45
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 43

def carrier_slug
  @carrier_slug
end

#currencyObject

ISO 4217 currency code



28
29
30
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 28

def currency
  @currency
end

#descriptionObject

Optional description



31
32
33
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 31

def description
  @description
end

#max_delivery_dateObject

Maximum delivery date (ISO 8601)



37
38
39
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 37

def max_delivery_date
  @max_delivery_date
end

#min_delivery_dateObject

Minimum delivery date (ISO 8601)



34
35
36
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 34

def min_delivery_date
  @min_delivery_date
end

#product_idObject

Carrier product ID



46
47
48
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 46

def product_id
  @product_id
end

#service_codeObject

Unique identifier for this shipping option



22
23
24
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 22

def service_code
  @service_code
end

#service_nameObject

Display name of the shipping option



19
20
21
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 19

def service_name
  @service_name
end

#shipping_rule_idObject

Shipping rule ID that generated this rate



49
50
51
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 49

def shipping_rule_id
  @shipping_rule_id
end

#total_priceObject

Total shipping price in cents as string



25
26
27
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 25

def total_price
  @total_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 52

def self.attribute_map
  {
    :'service_name' => :'serviceName',
    :'service_code' => :'serviceCode',
    :'total_price' => :'totalPrice',
    :'currency' => :'currency',
    :'description' => :'description',
    :'min_delivery_date' => :'minDeliveryDate',
    :'max_delivery_date' => :'maxDeliveryDate',
    :'carrier_name' => :'carrierName',
    :'carrier_slug' => :'carrierSlug',
    :'product_id' => :'productId',
    :'shipping_rule_id' => :'shippingRuleId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 79

def self.openapi_types
  {
    :'service_name' => :'String',
    :'service_code' => :'String',
    :'total_price' => :'String',
    :'currency' => :'String',
    :'description' => :'String',
    :'min_delivery_date' => :'String',
    :'max_delivery_date' => :'String',
    :'carrier_name' => :'String',
    :'carrier_slug' => :'String',
    :'product_id' => :'String',
    :'shipping_rule_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      service_name == o.service_name &&
      service_code == o.service_code &&
      total_price == o.total_price &&
      currency == o.currency &&
      description == o.description &&
      min_delivery_date == o.min_delivery_date &&
      max_delivery_date == o.max_delivery_date &&
      carrier_name == o.carrier_name &&
      carrier_slug == o.carrier_slug &&
      product_id == o.product_id &&
      shipping_rule_id == o.shipping_rule_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 288

def hash
  [service_name, service_code, total_price, currency, description, min_delivery_date, max_delivery_date, carrier_name, carrier_slug, product_id, shipping_rule_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @service_name.nil?
    invalid_properties.push('invalid value for "service_name", service_name cannot be nil.')
  end

  if @service_code.nil?
    invalid_properties.push('invalid value for "service_code", service_code cannot be nil.')
  end

  if @total_price.nil?
    invalid_properties.push('invalid value for "total_price", total_price cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @shipping_rule_id.nil?
    invalid_properties.push('invalid value for "shipping_rule_id", shipping_rule_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
# File 'lib/zippendo/models/create_shipping_quote200_response_rates_inner.rb', line 202

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @service_name.nil?
  return false if @service_code.nil?
  return false if @total_price.nil?
  return false if @currency.nil?
  return false if @shipping_rule_id.nil?
  true
end