Class: Zippendo::CreateShippingQuoteRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/create_shipping_quote_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateShippingQuoteRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShippingQuoteRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShippingQuoteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'destination')
    self.destination = attributes[:'destination']
  else
    self.destination = nil
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'total_price_cents')
    self.total_price_cents = attributes[:'total_price_cents']
  end
end

Instance Attribute Details

#currencyObject

ISO 4217 currency code



24
25
26
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 24

def currency
  @currency
end

#destinationObject

Returns the value of attribute destination.



18
19
20
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 18

def destination
  @destination
end

#itemsObject

Cart items



21
22
23
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 21

def items
  @items
end

#total_price_centsObject

Total price in cents after discounts (optional, enables total-based conditions)



27
28
29
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 27

def total_price_cents
  @total_price_cents
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 30

def self.attribute_map
  {
    :'destination' => :'destination',
    :'items' => :'items',
    :'currency' => :'currency',
    :'total_price_cents' => :'totalPriceCents'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 50

def self.openapi_types
  {
    :'destination' => :'CreateShippingQuoteRequestDestination',
    :'items' => :'Array<CreateShippingQuoteRequestItemsInner>',
    :'currency' => :'String',
    :'total_price_cents' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



214
215
216
217
218
219
220
221
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      destination == o.destination &&
      items == o.items &&
      currency == o.currency &&
      total_price_cents == o.total_price_cents
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 231

def hash
  [destination, items, currency, total_price_cents].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @destination.nil?
    invalid_properties.push('invalid value for "destination", destination cannot be nil.')
  end

  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  if @items.length < 1
    invalid_properties.push('invalid value for "items", number of items must be greater than or equal to 1.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if @currency.to_s.length < 3
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.')
  end

  if !@total_price_cents.nil? && @total_price_cents < 0
    invalid_properties.push('invalid value for "total_price_cents", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/zippendo/models/create_shipping_quote_request.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @destination.nil?
  return false if @items.nil?
  return false if @items.length < 1
  return false if @currency.nil?
  return false if @currency.to_s.length > 3
  return false if @currency.to_s.length < 3
  return false if !@total_price_cents.nil? && @total_price_cents < 0
  true
end