Class: Zippendo::CreateShippingQuoteRequestDestination
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateShippingQuoteRequestDestination
- Defined in:
- lib/zippendo/models/create_shipping_quote_request_destination.rb
Instance Attribute Summary collapse
-
#address1 ⇒ Object
Street address line 1.
-
#address2 ⇒ Object
Street address line 2.
-
#city ⇒ Object
City name.
-
#country ⇒ Object
ISO 3166-1 alpha-2 country code.
-
#postal_code ⇒ Object
Postal/ZIP code.
-
#province ⇒ Object
State/province code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateShippingQuoteRequestDestination
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateShippingQuoteRequestDestination
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShippingQuoteRequestDestination` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShippingQuoteRequestDestination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'country') self.country = attributes[:'country'] else self.country = nil end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'province') self.province = attributes[:'province'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'address1') self.address1 = attributes[:'address1'] end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end end |
Instance Attribute Details
#address1 ⇒ Object
Street address line 1
31 32 33 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 31 def address1 @address1 end |
#address2 ⇒ Object
Street address line 2
34 35 36 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 34 def address2 @address2 end |
#city ⇒ Object
City name
28 29 30 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 28 def city @city end |
#country ⇒ Object
ISO 3166-1 alpha-2 country code
19 20 21 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 19 def country @country end |
#postal_code ⇒ Object
Postal/ZIP code
22 23 24 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 22 def postal_code @postal_code end |
#province ⇒ Object
State/province code
25 26 27 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 25 def province @province end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 37 def self.attribute_map { :'country' => :'country', :'postal_code' => :'postalCode', :'province' => :'province', :'city' => :'city', :'address1' => :'address1', :'address2' => :'address2' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 59 def self.openapi_types { :'country' => :'String', :'postal_code' => :'String', :'province' => :'String', :'city' => :'String', :'address1' => :'String', :'address2' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && country == o.country && postal_code == o.postal_code && province == o.province && city == o.city && address1 == o.address1 && address2 == o.address2 end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 188 def hash [country, postal_code, province, city, address1, address2].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @country.nil? invalid_properties.push('invalid value for "country", country cannot be nil.') end if @country.to_s.length > 2 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 2.') end if @country.to_s.length < 2 invalid_properties.push('invalid value for "country", the character length must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 145 146 147 |
# File 'lib/zippendo/models/create_shipping_quote_request_destination.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @country.nil? return false if @country.to_s.length > 2 return false if @country.to_s.length < 2 true end |