Class: Zippendo::CreateShippingQuoteRequestItemsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateShippingQuoteRequestItemsInner
- Defined in:
- lib/zippendo/models/create_shipping_quote_request_items_inner.rb
Instance Attribute Summary collapse
-
#grams ⇒ Object
Weight in grams.
-
#name ⇒ Object
Item name.
-
#price ⇒ Object
Price in cents.
-
#product_id ⇒ Object
Product ID.
-
#quantity ⇒ Object
Quantity.
-
#sku ⇒ Object
SKU identifier.
-
#variant_id ⇒ Object
Variant ID.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateShippingQuoteRequestItemsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateShippingQuoteRequestItemsInner
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateShippingQuoteRequestItemsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateShippingQuoteRequestItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'grams') self.grams = attributes[:'grams'] else self.grams = nil end if attributes.key?(:'price') self.price = attributes[:'price'] else self.price = nil end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.key?(:'variant_id') self.variant_id = attributes[:'variant_id'] end end |
Instance Attribute Details
#grams ⇒ Object
Weight in grams
28 29 30 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 28 def grams @grams end |
#name ⇒ Object
Item name
19 20 21 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 19 def name @name end |
#price ⇒ Object
Price in cents
31 32 33 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 31 def price @price end |
#product_id ⇒ Object
Product ID
34 35 36 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 34 def product_id @product_id end |
#quantity ⇒ Object
Quantity
25 26 27 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 25 def quantity @quantity end |
#sku ⇒ Object
SKU identifier
22 23 24 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 22 def sku @sku end |
#variant_id ⇒ Object
Variant ID
37 38 39 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 37 def variant_id @variant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 40 def self.attribute_map { :'name' => :'name', :'sku' => :'sku', :'quantity' => :'quantity', :'grams' => :'grams', :'price' => :'price', :'product_id' => :'productId', :'variant_id' => :'variantId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 76 def self.openapi_nullable Set.new([ :'sku', :'product_id', :'variant_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 63 def self.openapi_types { :'name' => :'String', :'sku' => :'String', :'quantity' => :'Integer', :'grams' => :'Float', :'price' => :'Float', :'product_id' => :'String', :'variant_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && sku == o.sku && quantity == o.quantity && grams == o.grams && price == o.price && product_id == o.product_id && variant_id == o.variant_id end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 270 def hash [name, sku, quantity, grams, price, product_id, variant_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end if @quantity > 9007199254740991 invalid_properties.push('invalid value for "quantity", must be smaller than or equal to 9007199254740991.') end if @quantity < 1 invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.') end if @grams.nil? invalid_properties.push('invalid value for "grams", grams cannot be nil.') end if @grams < 0 invalid_properties.push('invalid value for "grams", must be greater than or equal to 0.') end if @price.nil? invalid_properties.push('invalid value for "price", price cannot be nil.') end if @price < 0 invalid_properties.push('invalid value for "price", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zippendo/models/create_shipping_quote_request_items_inner.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @quantity.nil? return false if @quantity > 9007199254740991 return false if @quantity < 1 return false if @grams.nil? return false if @grams < 0 return false if @price.nil? return false if @price < 0 true end |