Class: Zippendo::GetOrder200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/get_order200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetOrder200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/zippendo/models/get_order200_response.rb', line 182

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::GetOrder200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::GetOrder200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'order_number')
    self.order_number = attributes[:'order_number']
  else
    self.order_number = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'customer_name')
    self.customer_name = attributes[:'customer_name']
  end

  if attributes.key?(:'customer_email')
    self.customer_email = attributes[:'customer_email']
  end

  if attributes.key?(:'shipping_address')
    self.shipping_address = attributes[:'shipping_address']
  end

  if attributes.key?(:'order_lines')
    if (value = attributes[:'order_lines']).is_a?(Array)
      self.order_lines = value
    end
  else
    self.order_lines = nil
  end

  if attributes.key?(:'subtotal_amount')
    self.subtotal_amount = attributes[:'subtotal_amount']
  end

  if attributes.key?(:'total_amount')
    self.total_amount = attributes[:'total_amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'shipping_rule_id')
    self.shipping_rule_id = attributes[:'shipping_rule_id']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'external_data')
    if (value = attributes[:'external_data']).is_a?(Hash)
      self.external_data = value
    end
  end

  if attributes.key?(:'order_channel_id')
    self.order_channel_id = attributes[:'order_channel_id']
  else
    self.order_channel_id = nil
  end

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  else
    self.org_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'order_channel')
    self.order_channel = attributes[:'order_channel']
  else
    self.order_channel = nil
  end

  if attributes.key?(:'shipping_rule')
    self.shipping_rule = attributes[:'shipping_rule']
  end

  if attributes.key?(:'shipments')
    if (value = attributes[:'shipments']).is_a?(Array)
      self.shipments = value
    end
  else
    self.shipments = nil
  end
end

Instance Attribute Details

#created_atObject

Creation timestamp (ISO 8601).



66
67
68
# File 'lib/zippendo/models/get_order200_response.rb', line 66

def created_at
  @created_at
end

#currencyObject

ISO 4217 currency code.



45
46
47
# File 'lib/zippendo/models/get_order200_response.rb', line 45

def currency
  @currency
end

#customer_emailObject

Customer email address.



31
32
33
# File 'lib/zippendo/models/get_order200_response.rb', line 31

def customer_email
  @customer_email
end

#customer_nameObject

Customer full name.



28
29
30
# File 'lib/zippendo/models/get_order200_response.rb', line 28

def customer_name
  @customer_name
end

#external_dataObject

Raw platform-specific payload for reference.



57
58
59
# File 'lib/zippendo/models/get_order200_response.rb', line 57

def external_data
  @external_data
end

#external_idObject

Identifier of the order in the source platform.



25
26
27
# File 'lib/zippendo/models/get_order200_response.rb', line 25

def external_id
  @external_id
end

#idObject

Unique order ID.



19
20
21
# File 'lib/zippendo/models/get_order200_response.rb', line 19

def id
  @id
end

#notesObject

Free-form internal notes.



54
55
56
# File 'lib/zippendo/models/get_order200_response.rb', line 54

def notes
  @notes
end

#order_channelObject

Returns the value of attribute order_channel.



71
72
73
# File 'lib/zippendo/models/get_order200_response.rb', line 71

def order_channel
  @order_channel
end

#order_channel_idObject

ID of the order channel this order belongs to.



60
61
62
# File 'lib/zippendo/models/get_order200_response.rb', line 60

def order_channel_id
  @order_channel_id
end

#order_linesObject

Line items in the order.



36
37
38
# File 'lib/zippendo/models/get_order200_response.rb', line 36

def order_lines
  @order_lines
end

#order_numberObject

Human-readable order number.



22
23
24
# File 'lib/zippendo/models/get_order200_response.rb', line 22

def order_number
  @order_number
end

#org_idObject

Owning organization ID.



63
64
65
# File 'lib/zippendo/models/get_order200_response.rb', line 63

def org_id
  @org_id
end

#shipmentsObject

Returns the value of attribute shipments.



75
76
77
# File 'lib/zippendo/models/get_order200_response.rb', line 75

def shipments
  @shipments
end

#shipping_addressObject

Returns the value of attribute shipping_address.



33
34
35
# File 'lib/zippendo/models/get_order200_response.rb', line 33

def shipping_address
  @shipping_address
end

#shipping_ruleObject

Returns the value of attribute shipping_rule.



73
74
75
# File 'lib/zippendo/models/get_order200_response.rb', line 73

def shipping_rule
  @shipping_rule
end

#shipping_rule_idObject

ID of the applied shipping rule.



51
52
53
# File 'lib/zippendo/models/get_order200_response.rb', line 51

def shipping_rule_id
  @shipping_rule_id
end

#statusObject

Order fulfilment status derived from its shipments.



48
49
50
# File 'lib/zippendo/models/get_order200_response.rb', line 48

def status
  @status
end

#subtotal_amountObject

Order subtotal before shipping and tax.



39
40
41
# File 'lib/zippendo/models/get_order200_response.rb', line 39

def subtotal_amount
  @subtotal_amount
end

#total_amountObject

Order grand total.



42
43
44
# File 'lib/zippendo/models/get_order200_response.rb', line 42

def total_amount
  @total_amount
end

#updated_atObject

Last update timestamp (ISO 8601).



69
70
71
# File 'lib/zippendo/models/get_order200_response.rb', line 69

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



127
128
129
# File 'lib/zippendo/models/get_order200_response.rb', line 127

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



132
133
134
# File 'lib/zippendo/models/get_order200_response.rb', line 132

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/zippendo/models/get_order200_response.rb', line 100

def self.attribute_map
  {
    :'id' => :'id',
    :'order_number' => :'orderNumber',
    :'external_id' => :'externalId',
    :'customer_name' => :'customerName',
    :'customer_email' => :'customerEmail',
    :'shipping_address' => :'shippingAddress',
    :'order_lines' => :'orderLines',
    :'subtotal_amount' => :'subtotalAmount',
    :'total_amount' => :'totalAmount',
    :'currency' => :'currency',
    :'status' => :'status',
    :'shipping_rule_id' => :'shippingRuleId',
    :'notes' => :'notes',
    :'external_data' => :'externalData',
    :'order_channel_id' => :'orderChannelId',
    :'org_id' => :'orgId',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'order_channel' => :'orderChannel',
    :'shipping_rule' => :'shippingRule',
    :'shipments' => :'shipments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/zippendo/models/get_order200_response.rb', line 517

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zippendo/models/get_order200_response.rb', line 164

def self.openapi_nullable
  Set.new([
    :'external_id',
    :'customer_name',
    :'customer_email',
    :'shipping_address',
    :'subtotal_amount',
    :'total_amount',
    :'currency',
    :'shipping_rule_id',
    :'notes',
    :'external_data',
    :'shipping_rule',
  ])
end

.openapi_typesObject

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zippendo/models/get_order200_response.rb', line 137

def self.openapi_types
  {
    :'id' => :'String',
    :'order_number' => :'String',
    :'external_id' => :'String',
    :'customer_name' => :'String',
    :'customer_email' => :'String',
    :'shipping_address' => :'CreateOrder201ResponseShippingAddress',
    :'order_lines' => :'Array<CreateOrder201ResponseOrderLinesInner>',
    :'subtotal_amount' => :'Float',
    :'total_amount' => :'Float',
    :'currency' => :'String',
    :'status' => :'String',
    :'shipping_rule_id' => :'String',
    :'notes' => :'String',
    :'external_data' => :'Hash<String, Object>',
    :'order_channel_id' => :'String',
    :'org_id' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'order_channel' => :'ListOrders200ResponseDataInnerOrderChannel',
    :'shipping_rule' => :'GetOrder200ResponseShippingRule',
    :'shipments' => :'Array<GetOrder200ResponseShipmentsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/zippendo/models/get_order200_response.rb', line 476

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      order_number == o.order_number &&
      external_id == o.external_id &&
      customer_name == o.customer_name &&
      customer_email == o.customer_email &&
      shipping_address == o.shipping_address &&
      order_lines == o.order_lines &&
      subtotal_amount == o.subtotal_amount &&
      total_amount == o.total_amount &&
      currency == o.currency &&
      status == o.status &&
      shipping_rule_id == o.shipping_rule_id &&
      notes == o.notes &&
      external_data == o.external_data &&
      order_channel_id == o.order_channel_id &&
      org_id == o.org_id &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      order_channel == o.order_channel &&
      shipping_rule == o.shipping_rule &&
      shipments == o.shipments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


504
505
506
# File 'lib/zippendo/models/get_order200_response.rb', line 504

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



510
511
512
# File 'lib/zippendo/models/get_order200_response.rb', line 510

def hash
  [id, order_number, external_id, customer_name, customer_email, shipping_address, order_lines, subtotal_amount, total_amount, currency, status, shipping_rule_id, notes, external_data, order_channel_id, org_id, created_at, updated_at, order_channel, shipping_rule, shipments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/zippendo/models/get_order200_response.rb', line 309

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @order_number.nil?
    invalid_properties.push('invalid value for "order_number", order_number cannot be nil.')
  end

  if @order_lines.nil?
    invalid_properties.push('invalid value for "order_lines", order_lines cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @order_channel_id.nil?
    invalid_properties.push('invalid value for "order_channel_id", order_channel_id cannot be nil.')
  end

  if @org_id.nil?
    invalid_properties.push('invalid value for "org_id", org_id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @order_channel.nil?
    invalid_properties.push('invalid value for "order_channel", order_channel cannot be nil.')
  end

  if @shipments.nil?
    invalid_properties.push('invalid value for "shipments", shipments cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/zippendo/models/get_order200_response.rb', line 539

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/zippendo/models/get_order200_response.rb', line 357

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @order_number.nil?
  return false if @order_lines.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "processing", "partially_fulfilled", "fulfilled", "error", "cancelled"])
  return false unless status_validator.valid?(@status)
  return false if @order_channel_id.nil?
  return false if @org_id.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @order_channel.nil?
  return false if @shipments.nil?
  true
end