Class: Zippendo::GetOrder200ResponseShippingRule

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/get_order200_response_shipping_rule.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetOrder200ResponseShippingRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::GetOrder200ResponseShippingRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::GetOrder200ResponseShippingRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'carrier_id')
    self.carrier_id = attributes[:'carrier_id']
  else
    self.carrier_id = nil
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  else
    self.product_id = nil
  end

  if attributes.key?(:'services')
    if (value = attributes[:'services']).is_a?(Array)
      self.services = value
    end
  else
    self.services = nil
  end

  if attributes.key?(:'address_id')
    self.address_id = attributes[:'address_id']
  else
    self.address_id = nil
  end

  if attributes.key?(:'return_shipping_rule_id')
    self.return_shipping_rule_id = attributes[:'return_shipping_rule_id']
  end

  if attributes.key?(:'auto_create_return_shipment')
    self.auto_create_return_shipment = attributes[:'auto_create_return_shipment']
  end

  if attributes.key?(:'auto_print_labels')
    self.auto_print_labels = attributes[:'auto_print_labels']
  end

  if attributes.key?(:'auto_print_documents')
    self.auto_print_documents = attributes[:'auto_print_documents']
  end

  if attributes.key?(:'label_printer_id')
    self.label_printer_id = attributes[:'label_printer_id']
  end

  if attributes.key?(:'document_printer_id')
    self.document_printer_id = attributes[:'document_printer_id']
  end
end

Instance Attribute Details

#address_idObject

Sender address applied by the rule.



34
35
36
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 34

def address_id
  @address_id
end

#auto_create_return_shipmentObject

Whether a return shipment is created automatically.



40
41
42
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 40

def auto_create_return_shipment
  @auto_create_return_shipment
end

#auto_print_documentsObject

Whether documents are printed automatically on send.



46
47
48
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 46

def auto_print_documents
  @auto_print_documents
end

#auto_print_labelsObject

Whether labels are printed automatically on send.



43
44
45
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 43

def auto_print_labels
  @auto_print_labels
end

#carrier_idObject

Carrier applied by the rule.



25
26
27
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 25

def carrier_id
  @carrier_id
end

#document_printer_idObject

Printer used for documents.



52
53
54
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 52

def document_printer_id
  @document_printer_id
end

#idObject

Unique shipping rule identifier.



19
20
21
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 19

def id
  @id
end

#label_printer_idObject

Printer used for labels.



49
50
51
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 49

def label_printer_id
  @label_printer_id
end

#nameObject

Display name of the shipping rule.



22
23
24
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 22

def name
  @name
end

#product_idObject

Carrier product applied by the rule.



28
29
30
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 28

def product_id
  @product_id
end

#return_shipping_rule_idObject

ID of the linked return shipping rule.



37
38
39
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 37

def return_shipping_rule_id
  @return_shipping_rule_id
end

#servicesObject

Additional service codes applied by the rule.



31
32
33
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 31

def services
  @services
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'carrier_id' => :'carrierId',
    :'product_id' => :'productId',
    :'services' => :'services',
    :'address_id' => :'addressId',
    :'return_shipping_rule_id' => :'returnShippingRuleId',
    :'auto_create_return_shipment' => :'autoCreateReturnShipment',
    :'auto_print_labels' => :'autoPrintLabels',
    :'auto_print_documents' => :'autoPrintDocuments',
    :'label_printer_id' => :'labelPrinterId',
    :'document_printer_id' => :'documentPrinterId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 327

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
105
106
107
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 101

def self.openapi_nullable
  Set.new([
    :'return_shipping_rule_id',
    :'label_printer_id',
    :'document_printer_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 83

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'carrier_id' => :'String',
    :'product_id' => :'String',
    :'services' => :'Array<String>',
    :'address_id' => :'String',
    :'return_shipping_rule_id' => :'String',
    :'auto_create_return_shipment' => :'Boolean',
    :'auto_print_labels' => :'Boolean',
    :'auto_print_documents' => :'Boolean',
    :'label_printer_id' => :'String',
    :'document_printer_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      carrier_id == o.carrier_id &&
      product_id == o.product_id &&
      services == o.services &&
      address_id == o.address_id &&
      return_shipping_rule_id == o.return_shipping_rule_id &&
      auto_create_return_shipment == o.auto_create_return_shipment &&
      auto_print_labels == o.auto_print_labels &&
      auto_print_documents == o.auto_print_documents &&
      label_printer_id == o.label_printer_id &&
      document_printer_id == o.document_printer_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 314

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



320
321
322
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 320

def hash
  [id, name, carrier_id, product_id, services, address_id, return_shipping_rule_id, auto_create_return_shipment, auto_print_labels, auto_print_documents, label_printer_id, document_printer_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 190

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @carrier_id.nil?
    invalid_properties.push('invalid value for "carrier_id", carrier_id cannot be nil.')
  end

  if @product_id.nil?
    invalid_properties.push('invalid value for "product_id", product_id cannot be nil.')
  end

  if @services.nil?
    invalid_properties.push('invalid value for "services", services cannot be nil.')
  end

  if @address_id.nil?
    invalid_properties.push('invalid value for "address_id", address_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 349

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
227
228
229
230
231
# File 'lib/zippendo/models/get_order200_response_shipping_rule.rb', line 222

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @carrier_id.nil?
  return false if @product_id.nil?
  return false if @services.nil?
  return false if @address_id.nil?
  true
end