Class: Zippendo::GetOrg200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/get_org200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetOrg200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zippendo/models/get_org200_response.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::GetOrg200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::GetOrg200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = 'DKK'
  end

  if attributes.key?(:'vat_number')
    self.vat_number = attributes[:'vat_number']
  end

  if attributes.key?(:'billing_email')
    self.billing_email = attributes[:'billing_email']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'address_line1')
    self.address_line1 = attributes[:'address_line1']
  end

  if attributes.key?(:'address_line2')
    self.address_line2 = attributes[:'address_line2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'customs')
    if (value = attributes[:'customs']).is_a?(Hash)
      self.customs = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'_count')
    self._count = attributes[:'_count']
  else
    self._count = nil
  end
end

Instance Attribute Details

#_countObject

Returns the value of attribute _count.



66
67
68
# File 'lib/zippendo/models/get_org200_response.rb', line 66

def _count
  @_count
end

#address_line1Object

Address line 1



43
44
45
# File 'lib/zippendo/models/get_org200_response.rb', line 43

def address_line1
  @address_line1
end

#address_line2Object

Address line 2



46
47
48
# File 'lib/zippendo/models/get_org200_response.rb', line 46

def address_line2
  @address_line2
end

#billing_emailObject

Billing email for invoices



37
38
39
# File 'lib/zippendo/models/get_org200_response.rb', line 37

def billing_email
  @billing_email
end

#cityObject

City



49
50
51
# File 'lib/zippendo/models/get_org200_response.rb', line 49

def city
  @city
end

#company_nameObject

Legal company name



40
41
42
# File 'lib/zippendo/models/get_org200_response.rb', line 40

def company_name
  @company_name
end

#countryObject

Country (ISO 3166-1 alpha-2 code)



55
56
57
# File 'lib/zippendo/models/get_org200_response.rb', line 55

def country
  @country
end

#created_atObject

Creation timestamp (ISO 8601)



61
62
63
# File 'lib/zippendo/models/get_org200_response.rb', line 61

def created_at
  @created_at
end

#currencyObject

Billing currency (ISO 4217 code)



31
32
33
# File 'lib/zippendo/models/get_org200_response.rb', line 31

def currency
  @currency
end

#customsObject

Customs identifiers keyed by type



58
59
60
# File 'lib/zippendo/models/get_org200_response.rb', line 58

def customs
  @customs
end

#descriptionObject

Organization description



28
29
30
# File 'lib/zippendo/models/get_org200_response.rb', line 28

def description
  @description
end

#idObject

Unique organization identifier



19
20
21
# File 'lib/zippendo/models/get_org200_response.rb', line 19

def id
  @id
end

#nameObject

Organization name



22
23
24
# File 'lib/zippendo/models/get_org200_response.rb', line 22

def name
  @name
end

#postal_codeObject

Postal code



52
53
54
# File 'lib/zippendo/models/get_org200_response.rb', line 52

def postal_code
  @postal_code
end

#slugObject

Organization URL slug (unique identifier)



25
26
27
# File 'lib/zippendo/models/get_org200_response.rb', line 25

def slug
  @slug
end

#updated_atObject

Last update timestamp (ISO 8601)



64
65
66
# File 'lib/zippendo/models/get_org200_response.rb', line 64

def updated_at
  @updated_at
end

#vat_numberObject

Company VAT/tax ID for invoices



34
35
36
# File 'lib/zippendo/models/get_org200_response.rb', line 34

def vat_number
  @vat_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/zippendo/models/get_org200_response.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/zippendo/models/get_org200_response.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zippendo/models/get_org200_response.rb', line 69

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'description' => :'description',
    :'currency' => :'currency',
    :'vat_number' => :'vatNumber',
    :'billing_email' => :'billingEmail',
    :'company_name' => :'companyName',
    :'address_line1' => :'addressLine1',
    :'address_line2' => :'addressLine2',
    :'city' => :'city',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'customs' => :'customs',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'_count' => :'_count'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/zippendo/models/get_org200_response.rb', line 402

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zippendo/models/get_org200_response.rb', line 125

def self.openapi_nullable
  Set.new([
    :'description',
    :'vat_number',
    :'billing_email',
    :'company_name',
    :'address_line1',
    :'address_line2',
    :'city',
    :'postal_code',
    :'country',
    :'customs',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/zippendo/models/get_org200_response.rb', line 102

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'description' => :'String',
    :'currency' => :'String',
    :'vat_number' => :'String',
    :'billing_email' => :'String',
    :'company_name' => :'String',
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'city' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'customs' => :'Hash<String, String>',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'_count' => :'GetOrg200ResponseCount'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/zippendo/models/get_org200_response.rb', line 365

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      slug == o.slug &&
      description == o.description &&
      currency == o.currency &&
      vat_number == o.vat_number &&
      billing_email == o.billing_email &&
      company_name == o.company_name &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      city == o.city &&
      postal_code == o.postal_code &&
      country == o.country &&
      customs == o.customs &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      _count == o._count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


389
390
391
# File 'lib/zippendo/models/get_org200_response.rb', line 389

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



395
396
397
# File 'lib/zippendo/models/get_org200_response.rb', line 395

def hash
  [id, name, slug, description, currency, vat_number, billing_email, company_name, address_line1, address_line2, city, postal_code, country, customs, created_at, updated_at, _count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/zippendo/models/get_org200_response.rb', line 245

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @_count.nil?
    invalid_properties.push('invalid value for "_count", _count cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/zippendo/models/get_org200_response.rb', line 424

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



281
282
283
284
285
286
287
288
289
290
291
# File 'lib/zippendo/models/get_org200_response.rb', line 281

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @currency.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @_count.nil?
  true
end