Class: Zippendo::ListCarriers200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/list_carriers200_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListCarriers200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListCarriers200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListCarriers200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'carrier_slug')
    self.carrier_slug = attributes[:'carrier_slug']
  else
    self.carrier_slug = nil
  end

  if attributes.key?(:'config')
    if (value = attributes[:'config']).is_a?(Hash)
      self.config = value
    end
  else
    self.config = nil
  end

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  else
    self.org_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'logo')
    self. = attributes[:'logo']
  end

  if attributes.key?(:'brand_color')
    self.brand_color = attributes[:'brand_color']
  end

  if attributes.key?(:'deprecated')
    self.deprecated = attributes[:'deprecated']
  end

  if attributes.key?(:'deprecation_message')
    self.deprecation_message = attributes[:'deprecation_message']
  end
end

Instance Attribute Details

#brand_colorObject

Carrier brand color (hex)



43
44
45
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 43

def brand_color
  @brand_color
end

#carrier_slugObject

Carrier slug identifier



25
26
27
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 25

def carrier_slug
  @carrier_slug
end

#configObject

Carrier configuration (required and optional fields)



28
29
30
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 28

def config
  @config
end

#created_atObject

Creation timestamp (ISO 8601)



34
35
36
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 34

def created_at
  @created_at
end

#deprecatedObject

Whether this carrier integration is deprecated (still works, but discouraged)



46
47
48
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 46

def deprecated
  @deprecated
end

#deprecation_messageObject

Guidance shown alongside the deprecated tag (e.g. what to migrate to)



49
50
51
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 49

def deprecation_message
  @deprecation_message
end

#idObject

Unique carrier identifier



19
20
21
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 19

def id
  @id
end

#logoObject

Carrier logo URL



40
41
42
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 40

def 
  @logo
end

#nameObject

Carrier display name



22
23
24
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 22

def name
  @name
end

#org_idObject

Owning organization ID



31
32
33
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 31

def org_id
  @org_id
end

#updated_atObject

Last update timestamp (ISO 8601)



37
38
39
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 37

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'carrier_slug' => :'carrierSlug',
    :'config' => :'config',
    :'org_id' => :'orgId',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'logo' => :'logo',
    :'brand_color' => :'brandColor',
    :'deprecated' => :'deprecated',
    :'deprecation_message' => :'deprecationMessage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 79

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'carrier_slug' => :'String',
    :'config' => :'Hash<String, ListCarriers200ResponseDataInnerConfigValue>',
    :'org_id' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'logo' => :'String',
    :'brand_color' => :'String',
    :'deprecated' => :'Boolean',
    :'deprecation_message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      carrier_slug == o.carrier_slug &&
      config == o.config &&
      org_id == o.org_id &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
       == o. &&
      brand_color == o.brand_color &&
      deprecated == o.deprecated &&
      deprecation_message == o.deprecation_message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 324

def hash
  [id, name, carrier_slug, config, org_id, created_at, updated_at, , brand_color, deprecated, deprecation_message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @carrier_slug.nil?
    invalid_properties.push('invalid value for "carrier_slug", carrier_slug cannot be nil.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  if @org_id.nil?
    invalid_properties.push('invalid value for "org_id", org_id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zippendo/models/list_carriers200_response_data_inner.rb', line 216

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @carrier_slug.nil?
  return false if @config.nil?
  return false if @org_id.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end