Class: Zippendo::ListShipments200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/list_shipments200_response_data_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListShipments200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListShipments200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListShipments200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  else
    self.reference = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'carrier_settings')
    self.carrier_settings = attributes[:'carrier_settings']
  else
    self.carrier_settings = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  else
    self.brand_id = nil
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



35
36
37
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 35

def address
  @address
end

#brand_idObject

Brand this record belongs to, or null when it is organization-wide



33
34
35
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 33

def brand_id
  @brand_id
end

#carrier_settingsObject

Returns the value of attribute carrier_settings.



27
28
29
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 27

def carrier_settings
  @carrier_settings
end

#created_atObject

Timestamp when the shipment was created.



38
39
40
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 38

def created_at
  @created_at
end

#idObject

Unique shipment identifier.



19
20
21
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 19

def id
  @id
end

#referenceObject

Customer-facing shipment reference.



22
23
24
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 22

def reference
  @reference
end

#statusObject

Lifecycle status of the shipment.



30
31
32
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 30

def status
  @status
end

#typeObject

Direction of the shipment relative to the organization.



25
26
27
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 25

def type
  @type
end

#updated_atObject

Timestamp when the shipment was last updated.



41
42
43
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 41

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'reference' => :'reference',
    :'type' => :'type',
    :'carrier_settings' => :'carrierSettings',
    :'status' => :'status',
    :'brand_id' => :'brandId',
    :'address' => :'address',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 337

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
111
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 106

def self.openapi_nullable
  Set.new([
    :'brand_id',
    :'address',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'reference' => :'String',
    :'type' => :'String',
    :'carrier_settings' => :'ListShipments200ResponseDataInnerCarrierSettings',
    :'status' => :'String',
    :'brand_id' => :'String',
    :'address' => :'ListShipments200ResponseDataInnerAddress',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 308

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      reference == o.reference &&
      type == o.type &&
      carrier_settings == o.carrier_settings &&
      status == o.status &&
      brand_id == o.brand_id &&
      address == o.address &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


324
325
326
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 324

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



330
331
332
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 330

def hash
  [id, reference, type, carrier_settings, status, brand_id, address, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @carrier_settings.nil?
    invalid_properties.push('invalid value for "carrier_settings", carrier_settings cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zippendo/models/list_shipments200_response_data_inner.rb', line 220

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @reference.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["outbound", "inbound"])
  return false unless type_validator.valid?(@type)
  return false if @carrier_settings.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["draft", "pending", "processing", "dispatched", "partly_dispatched", "error", "cancelled", "on_hold"])
  return false unless status_validator.valid?(@status)
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end