Class: Zippendo::ListShipments200ResponseDataInnerCarrierSettings
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::ListShipments200ResponseDataInnerCarrierSettings
- Defined in:
- lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb
Instance Attribute Summary collapse
-
#additional_parameters ⇒ Object
Carrier-specific extra parameters as key/value pairs.
-
#carrier_id ⇒ Object
Identifier of the carrier to use.
-
#product_id ⇒ Object
Identifier of the carrier product/service.
-
#services ⇒ Object
Additional service codes requested from the carrier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListShipments200ResponseDataInnerCarrierSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListShipments200ResponseDataInnerCarrierSettings
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListShipments200ResponseDataInnerCarrierSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListShipments200ResponseDataInnerCarrierSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'carrier_id') self.carrier_id = attributes[:'carrier_id'] else self.carrier_id = nil end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] else self.product_id = nil end if attributes.key?(:'services') if (value = attributes[:'services']).is_a?(Array) self.services = value end else self.services = nil end if attributes.key?(:'additional_parameters') if (value = attributes[:'additional_parameters']).is_a?(Hash) self.additional_parameters = value end else self.additional_parameters = nil end end |
Instance Attribute Details
#additional_parameters ⇒ Object
Carrier-specific extra parameters as key/value pairs.
28 29 30 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 28 def additional_parameters @additional_parameters end |
#carrier_id ⇒ Object
Identifier of the carrier to use.
19 20 21 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 19 def carrier_id @carrier_id end |
#product_id ⇒ Object
Identifier of the carrier product/service.
22 23 24 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 22 def product_id @product_id end |
#services ⇒ Object
Additional service codes requested from the carrier.
25 26 27 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 25 def services @services end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 31 def self.attribute_map { :'carrier_id' => :'carrierId', :'product_id' => :'productId', :'services' => :'services', :'additional_parameters' => :'additionalParameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 212 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 51 def self.openapi_types { :'carrier_id' => :'String', :'product_id' => :'String', :'services' => :'Array<String>', :'additional_parameters' => :'Hash<String, ListShipments200ResponseDataInnerCarrierSettingsAdditionalParametersValue>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && carrier_id == o.carrier_id && product_id == o.product_id && services == o.services && additional_parameters == o.additional_parameters end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 205 def hash [carrier_id, product_id, services, additional_parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @carrier_id.nil? invalid_properties.push('invalid value for "carrier_id", carrier_id cannot be nil.') end if @product_id.nil? invalid_properties.push('invalid value for "product_id", product_id cannot be nil.') end if @services.nil? invalid_properties.push('invalid value for "services", services cannot be nil.') end if @additional_parameters.nil? invalid_properties.push('invalid value for "additional_parameters", additional_parameters cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 143 144 |
# File 'lib/zippendo/models/list_shipments200_response_data_inner_carrier_settings.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @carrier_id.nil? return false if @product_id.nil? return false if @services.nil? return false if @additional_parameters.nil? true end |