Class: Zippendo::ListShippingRules200ResponseDataInnerConditionsInnerOneOf3
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::ListShippingRules200ResponseDataInnerConditionsInnerOneOf3
- Defined in:
- lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#currency ⇒ Object
ISO 4217 currency code.
-
#operator ⇒ Object
Comparison operator.
-
#shipping_price ⇒ Object
Shipping price when condition matches.
-
#type ⇒ Object
Condition type discriminator.
-
#value ⇒ Object
Quantity value to compare against.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListShippingRules200ResponseDataInnerConditionsInnerOneOf3
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListShippingRules200ResponseDataInnerConditionsInnerOneOf3
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListShippingRules200ResponseDataInnerConditionsInnerOneOf3` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListShippingRules200ResponseDataInnerConditionsInnerOneOf3`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'shipping_price') self.shipping_price = attributes[:'shipping_price'] else self.shipping_price = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end end |
Instance Attribute Details
#currency ⇒ Object
ISO 4217 currency code
31 32 33 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 31 def currency @currency end |
#operator ⇒ Object
Comparison operator
22 23 24 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 22 def operator @operator end |
#shipping_price ⇒ Object
Shipping price when condition matches
28 29 30 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 28 def shipping_price @shipping_price end |
#type ⇒ Object
Condition type discriminator
19 20 21 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 19 def type @type end |
#value ⇒ Object
Quantity value to compare against
25 26 27 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 25 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 56 def self.attribute_map { :'type' => :'type', :'operator' => :'operator', :'value' => :'value', :'shipping_price' => :'shippingPrice', :'currency' => :'currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 77 def self.openapi_types { :'type' => :'String', :'operator' => :'String', :'value' => :'Integer', :'shipping_price' => :'Float', :'currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && operator == o.operator && value == o.value && shipping_price == o.shipping_price && currency == o.currency end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 299 def hash [type, operator, value, shipping_price, currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @value > 9007199254740991 invalid_properties.push('invalid value for "value", must be smaller than or equal to 9007199254740991.') end if @value < 0 invalid_properties.push('invalid value for "value", must be greater than or equal to 0.') end if @shipping_price.nil? invalid_properties.push('invalid value for "shipping_price", shipping_price cannot be nil.') end if @shipping_price < 0 invalid_properties.push('invalid value for "shipping_price", must be greater than or equal to 0.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if @currency.to_s.length < 3 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zippendo/models/list_shipping_rules200_response_data_inner_conditions_inner_one_of3.rb', line 190 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["quantity"]) return false unless type_validator.valid?(@type) return false if @operator.nil? operator_validator = EnumAttributeValidator.new('String', ["gt", "gte", "lt", "lte", "eq"]) return false unless operator_validator.valid?(@operator) return false if @value.nil? return false if @value > 9007199254740991 return false if @value < 0 return false if @shipping_price.nil? return false if @shipping_price < 0 return false if @currency.nil? return false if @currency.to_s.length > 3 return false if @currency.to_s.length < 3 true end |