Class: Zippendo::OrdersApi
- Inherits:
-
Object
- Object
- Zippendo::OrdersApi
- Defined in:
- lib/zippendo/api/orders_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_order(org_id, create_order_request, opts = {}) ⇒ CreateOrder201Response
Create order Creates a new order under an existing order channel for the organization.
-
#create_order_with_http_info(org_id, create_order_request, opts = {}) ⇒ Array<(CreateOrder201Response, Integer, Hash)>
Create order Creates a new order under an existing order channel for the organization.
-
#delete_order(org_id, order_id, opts = {}) ⇒ RevokeApiToken200Response
Delete order Deletes an order.
-
#delete_order_with_http_info(org_id, order_id, opts = {}) ⇒ Array<(RevokeApiToken200Response, Integer, Hash)>
Delete order Deletes an order.
-
#get_order(org_id, order_id, opts = {}) ⇒ GetOrder200Response
Get order Returns a single order with its channel, shipping rule, shipments, and documents.
-
#get_order_with_http_info(org_id, order_id, opts = {}) ⇒ Array<(GetOrder200Response, Integer, Hash)>
Get order Returns a single order with its channel, shipping rule, shipments, and documents.
-
#initialize(api_client = ApiClient.default) ⇒ OrdersApi
constructor
A new instance of OrdersApi.
-
#list_orders(org_id, opts = {}) ⇒ ListOrders200Response
List orders Returns a paginated list of orders for an organization, filterable by status, channel, and search term.
-
#list_orders_with_http_info(org_id, opts = {}) ⇒ Array<(ListOrders200Response, Integer, Hash)>
List orders Returns a paginated list of orders for an organization, filterable by status, channel, and search term.
-
#update_order(org_id, order_id, update_order_request, opts = {}) ⇒ CreateOrder201Response
Update order Updates an order that is not yet fulfilled or cancelled.
-
#update_order_with_http_info(org_id, order_id, update_order_request, opts = {}) ⇒ Array<(CreateOrder201Response, Integer, Hash)>
Update order Updates an order that is not yet fulfilled or cancelled.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/orders_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_order(org_id, create_order_request, opts = {}) ⇒ CreateOrder201Response
Create order Creates a new order under an existing order channel for the organization.
28 29 30 31 |
# File 'lib/zippendo/api/orders_api.rb', line 28 def create_order(org_id, create_order_request, opts = {}) data, _status_code, _headers = create_order_with_http_info(org_id, create_order_request, opts) data end |
#create_order_with_http_info(org_id, create_order_request, opts = {}) ⇒ Array<(CreateOrder201Response, Integer, Hash)>
Create order Creates a new order under an existing order channel for the organization.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zippendo/api/orders_api.rb', line 39 def create_order_with_http_info(org_id, create_order_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.create_order ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrdersApi.create_order" end # verify the required parameter 'create_order_request' is set if @api_client.config.client_side_validation && create_order_request.nil? fail ArgumentError, "Missing the required parameter 'create_order_request' when calling OrdersApi.create_order" end # resource path local_var_path = '/orgs/{orgId}/orders'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_order_request) # return_type return_type = opts[:debug_return_type] || 'CreateOrder201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.create_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#create_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_order(org_id, order_id, opts = {}) ⇒ RevokeApiToken200Response
Delete order Deletes an order. Fails if the order has associated shipments.
102 103 104 105 |
# File 'lib/zippendo/api/orders_api.rb', line 102 def delete_order(org_id, order_id, opts = {}) data, _status_code, _headers = delete_order_with_http_info(org_id, order_id, opts) data end |
#delete_order_with_http_info(org_id, order_id, opts = {}) ⇒ Array<(RevokeApiToken200Response, Integer, Hash)>
Delete order Deletes an order. Fails if the order has associated shipments.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zippendo/api/orders_api.rb', line 113 def delete_order_with_http_info(org_id, order_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.delete_order ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrdersApi.delete_order" end # verify the required parameter 'order_id' is set if @api_client.config.client_side_validation && order_id.nil? fail ArgumentError, "Missing the required parameter 'order_id' when calling OrdersApi.delete_order" end # resource path local_var_path = '/orgs/{orgId}/orders/{orderId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{orderId}', CGI.escape(order_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RevokeApiToken200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.delete_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#delete_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_order(org_id, order_id, opts = {}) ⇒ GetOrder200Response
Get order Returns a single order with its channel, shipping rule, shipments, and documents.
171 172 173 174 |
# File 'lib/zippendo/api/orders_api.rb', line 171 def get_order(org_id, order_id, opts = {}) data, _status_code, _headers = get_order_with_http_info(org_id, order_id, opts) data end |
#get_order_with_http_info(org_id, order_id, opts = {}) ⇒ Array<(GetOrder200Response, Integer, Hash)>
Get order Returns a single order with its channel, shipping rule, shipments, and documents.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/zippendo/api/orders_api.rb', line 182 def get_order_with_http_info(org_id, order_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.get_order ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrdersApi.get_order" end # verify the required parameter 'order_id' is set if @api_client.config.client_side_validation && order_id.nil? fail ArgumentError, "Missing the required parameter 'order_id' when calling OrdersApi.get_order" end # resource path local_var_path = '/orgs/{orgId}/orders/{orderId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{orderId}', CGI.escape(order_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrder200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.get_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#get_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_orders(org_id, opts = {}) ⇒ ListOrders200Response
List orders Returns a paginated list of orders for an organization, filterable by status, channel, and search term.
244 245 246 247 |
# File 'lib/zippendo/api/orders_api.rb', line 244 def list_orders(org_id, opts = {}) data, _status_code, _headers = list_orders_with_http_info(org_id, opts) data end |
#list_orders_with_http_info(org_id, opts = {}) ⇒ Array<(ListOrders200Response, Integer, Hash)>
List orders Returns a paginated list of orders for an organization, filterable by status, channel, and search term.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/zippendo/api/orders_api.rb', line 259 def list_orders_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.list_orders ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrdersApi.list_orders" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling OrdersApi.list_orders, must be smaller than or equal to 9007199254740991.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling OrdersApi.list_orders, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrdersApi.list_orders, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrdersApi.list_orders, must be greater than or equal to 1.' end allowable_values = ["pending", "processing", "partially_fulfilled", "fulfilled", "error", "cancelled"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/orgs/{orgId}/orders'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'orderChannelId'] = opts[:'order_channel_id'] if !opts[:'order_channel_id'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListOrders200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.list_orders", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#list_orders\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_order(org_id, order_id, update_order_request, opts = {}) ⇒ CreateOrder201Response
Update order Updates an order that is not yet fulfilled or cancelled.
339 340 341 342 |
# File 'lib/zippendo/api/orders_api.rb', line 339 def update_order(org_id, order_id, update_order_request, opts = {}) data, _status_code, _headers = update_order_with_http_info(org_id, order_id, update_order_request, opts) data end |
#update_order_with_http_info(org_id, order_id, update_order_request, opts = {}) ⇒ Array<(CreateOrder201Response, Integer, Hash)>
Update order Updates an order that is not yet fulfilled or cancelled.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/zippendo/api/orders_api.rb', line 351 def update_order_with_http_info(org_id, order_id, update_order_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.update_order ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrdersApi.update_order" end # verify the required parameter 'order_id' is set if @api_client.config.client_side_validation && order_id.nil? fail ArgumentError, "Missing the required parameter 'order_id' when calling OrdersApi.update_order" end # verify the required parameter 'update_order_request' is set if @api_client.config.client_side_validation && update_order_request.nil? fail ArgumentError, "Missing the required parameter 'update_order_request' when calling OrdersApi.update_order" end # resource path local_var_path = '/orgs/{orgId}/orders/{orderId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{orderId}', CGI.escape(order_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_order_request) # return_type return_type = opts[:debug_return_type] || 'CreateOrder201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.update_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#update_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |