Class: Zippendo::QuotesApi
- Inherits:
-
Object
- Object
- Zippendo::QuotesApi
- Defined in:
- lib/zippendo/api/quotes_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_shipping_quote(org_id, create_shipping_quote_request, opts = {}) ⇒ CreateShippingQuote200Response
Calculate shipping rates Calculates shipping rates from configured shipping rules based on cart items and destination.
-
#create_shipping_quote_with_http_info(org_id, create_shipping_quote_request, opts = {}) ⇒ Array<(CreateShippingQuote200Response, Integer, Hash)>
Calculate shipping rates Calculates shipping rates from configured shipping rules based on cart items and destination.
-
#initialize(api_client = ApiClient.default) ⇒ QuotesApi
constructor
A new instance of QuotesApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/quotes_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_shipping_quote(org_id, create_shipping_quote_request, opts = {}) ⇒ CreateShippingQuote200Response
Calculate shipping rates Calculates shipping rates from configured shipping rules based on cart items and destination.
28 29 30 31 |
# File 'lib/zippendo/api/quotes_api.rb', line 28 def create_shipping_quote(org_id, create_shipping_quote_request, opts = {}) data, _status_code, _headers = create_shipping_quote_with_http_info(org_id, create_shipping_quote_request, opts) data end |
#create_shipping_quote_with_http_info(org_id, create_shipping_quote_request, opts = {}) ⇒ Array<(CreateShippingQuote200Response, Integer, Hash)>
Calculate shipping rates Calculates shipping rates from configured shipping rules based on cart items and destination.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zippendo/api/quotes_api.rb', line 39 def create_shipping_quote_with_http_info(org_id, create_shipping_quote_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: QuotesApi.create_shipping_quote ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling QuotesApi.create_shipping_quote" end # verify the required parameter 'create_shipping_quote_request' is set if @api_client.config.client_side_validation && create_shipping_quote_request.nil? fail ArgumentError, "Missing the required parameter 'create_shipping_quote_request' when calling QuotesApi.create_shipping_quote" end # resource path local_var_path = '/orgs/{orgId}/shipping-quote'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_shipping_quote_request) # return_type return_type = opts[:debug_return_type] || 'CreateShippingQuote200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"QuotesApi.create_shipping_quote", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: QuotesApi#create_shipping_quote\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |