Class: Zippendo::RulesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zippendo/api/rules_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RulesApi

Returns a new instance of RulesApi.



19
20
21
# File 'lib/zippendo/api/rules_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zippendo/api/rules_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_shipping_rule(org_id, create_shipping_rule_request, opts = {}) ⇒ CreateShippingRule201Response

Create shipping rule Creates a new shipping rule with conditions and carrier product for the organization.

Parameters:

  • org_id (String)

    Organization ID

  • create_shipping_rule_request (CreateShippingRuleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/zippendo/api/rules_api.rb', line 28

def create_shipping_rule(org_id, create_shipping_rule_request, opts = {})
  data, _status_code, _headers = create_shipping_rule_with_http_info(org_id, create_shipping_rule_request, opts)
  data
end

#create_shipping_rule_with_http_info(org_id, create_shipping_rule_request, opts = {}) ⇒ Array<(CreateShippingRule201Response, Integer, Hash)>

Create shipping rule Creates a new shipping rule with conditions and carrier product for the organization.

Parameters:

  • org_id (String)

    Organization ID

  • create_shipping_rule_request (CreateShippingRuleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zippendo/api/rules_api.rb', line 39

def create_shipping_rule_with_http_info(org_id, create_shipping_rule_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.create_shipping_rule ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling RulesApi.create_shipping_rule"
  end
  # verify the required parameter 'create_shipping_rule_request' is set
  if @api_client.config.client_side_validation && create_shipping_rule_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_shipping_rule_request' when calling RulesApi.create_shipping_rule"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/shipping-rules'.sub('{orgId}', CGI.escape(org_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_shipping_rule_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateShippingRule201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.create_shipping_rule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#create_shipping_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_shipping_rule(org_id, rule_id, opts = {}) ⇒ DeleteShippingRule200Response

Delete shipping rule Deletes a shipping rule belonging to the organization.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



102
103
104
105
# File 'lib/zippendo/api/rules_api.rb', line 102

def delete_shipping_rule(org_id, rule_id, opts = {})
  data, _status_code, _headers = delete_shipping_rule_with_http_info(org_id, rule_id, opts)
  data
end

#delete_shipping_rule_with_http_info(org_id, rule_id, opts = {}) ⇒ Array<(DeleteShippingRule200Response, Integer, Hash)>

Delete shipping rule Deletes a shipping rule belonging to the organization.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zippendo/api/rules_api.rb', line 113

def delete_shipping_rule_with_http_info(org_id, rule_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.delete_shipping_rule ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling RulesApi.delete_shipping_rule"
  end
  # verify the required parameter 'rule_id' is set
  if @api_client.config.client_side_validation && rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'rule_id' when calling RulesApi.delete_shipping_rule"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/shipping-rules/{ruleId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{ruleId}', CGI.escape(rule_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteShippingRule200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.delete_shipping_rule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#delete_shipping_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_shipping_rule(org_id, rule_id, opts = {}) ⇒ ListShippingRules200ResponseDataInner

Get shipping rule Returns a single shipping rule with its carrier, address and printer relations.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



171
172
173
174
# File 'lib/zippendo/api/rules_api.rb', line 171

def get_shipping_rule(org_id, rule_id, opts = {})
  data, _status_code, _headers = get_shipping_rule_with_http_info(org_id, rule_id, opts)
  data
end

#get_shipping_rule_with_http_info(org_id, rule_id, opts = {}) ⇒ Array<(ListShippingRules200ResponseDataInner, Integer, Hash)>

Get shipping rule Returns a single shipping rule with its carrier, address and printer relations.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zippendo/api/rules_api.rb', line 182

def get_shipping_rule_with_http_info(org_id, rule_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.get_shipping_rule ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling RulesApi.get_shipping_rule"
  end
  # verify the required parameter 'rule_id' is set
  if @api_client.config.client_side_validation && rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'rule_id' when calling RulesApi.get_shipping_rule"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/shipping-rules/{ruleId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{ruleId}', CGI.escape(rule_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListShippingRules200ResponseDataInner'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.get_shipping_rule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#get_shipping_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_shipping_rules(org_id, opts = {}) ⇒ ListShippingRules200Response

List shipping rules Returns a paginated list of shipping rules for the organization with their relations.

Parameters:

  • org_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Items per page (max 100) (default to 20)

Returns:



241
242
243
244
# File 'lib/zippendo/api/rules_api.rb', line 241

def list_shipping_rules(org_id, opts = {})
  data, _status_code, _headers = list_shipping_rules_with_http_info(org_id, opts)
  data
end

#list_shipping_rules_with_http_info(org_id, opts = {}) ⇒ Array<(ListShippingRules200Response, Integer, Hash)>

List shipping rules Returns a paginated list of shipping rules for the organization with their relations.

Parameters:

  • org_id (String)

    Organization ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Items per page (max 100) (default to 20)

Returns:



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/zippendo/api/rules_api.rb', line 253

def list_shipping_rules_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.list_shipping_rules ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling RulesApi.list_shipping_rules"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling RulesApi.list_shipping_rules, must be smaller than or equal to 9007199254740991.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling RulesApi.list_shipping_rules, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling RulesApi.list_shipping_rules, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling RulesApi.list_shipping_rules, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/orgs/{orgId}/shipping-rules'.sub('{orgId}', CGI.escape(org_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListShippingRules200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.list_shipping_rules",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#list_shipping_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_shipping_rule(org_id, rule_id, update_shipping_rule_request, opts = {}) ⇒ CreateShippingRule201Response

Update shipping rule Updates an existing shipping rule for the organization.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • update_shipping_rule_request (UpdateShippingRuleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



326
327
328
329
# File 'lib/zippendo/api/rules_api.rb', line 326

def update_shipping_rule(org_id, rule_id, update_shipping_rule_request, opts = {})
  data, _status_code, _headers = update_shipping_rule_with_http_info(org_id, rule_id, update_shipping_rule_request, opts)
  data
end

#update_shipping_rule_with_http_info(org_id, rule_id, update_shipping_rule_request, opts = {}) ⇒ Array<(CreateShippingRule201Response, Integer, Hash)>

Update shipping rule Updates an existing shipping rule for the organization.

Parameters:

  • org_id (String)

    Organization ID

  • rule_id (String)

    Shipping Rule ID

  • update_shipping_rule_request (UpdateShippingRuleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/zippendo/api/rules_api.rb', line 338

def update_shipping_rule_with_http_info(org_id, rule_id, update_shipping_rule_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RulesApi.update_shipping_rule ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling RulesApi.update_shipping_rule"
  end
  # verify the required parameter 'rule_id' is set
  if @api_client.config.client_side_validation && rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'rule_id' when calling RulesApi.update_shipping_rule"
  end
  # verify the required parameter 'update_shipping_rule_request' is set
  if @api_client.config.client_side_validation && update_shipping_rule_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_shipping_rule_request' when calling RulesApi.update_shipping_rule"
  end
  # resource path
  local_var_path = '/orgs/{orgId}/shipping-rules/{ruleId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{ruleId}', CGI.escape(rule_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_shipping_rule_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateShippingRule201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"RulesApi.update_shipping_rule",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RulesApi#update_shipping_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end