Class: Zippendo::SplitShipmentRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/split_shipment_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SplitShipmentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/zippendo/models/split_shipment_request.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::SplitShipmentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::SplitShipmentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'parcel_id')
    self.parcel_id = attributes[:'parcel_id']
  else
    self.parcel_id = nil
  end

  if attributes.key?(:'order_line_ids')
    if (value = attributes[:'order_line_ids']).is_a?(Array)
      self.order_line_ids = value
    end
  end

  if attributes.key?(:'carrier_id')
    self.carrier_id = attributes[:'carrier_id']
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  end

  if attributes.key?(:'services')
    if (value = attributes[:'services']).is_a?(Array)
      self.services = value
    end
  end

  if attributes.key?(:'additional_parameters')
    if (value = attributes[:'additional_parameters']).is_a?(Hash)
      self.additional_parameters = value
    end
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end
end

Instance Attribute Details

#additional_parametersObject

Carrier-specific parameters for the new shipment.



34
35
36
# File 'lib/zippendo/models/split_shipment_request.rb', line 34

def additional_parameters
  @additional_parameters
end

#carrier_idObject

Carrier for the new shipment. Copied from the original if omitted.



25
26
27
# File 'lib/zippendo/models/split_shipment_request.rb', line 25

def carrier_id
  @carrier_id
end

#order_line_idsObject

Order line IDs to move. If omitted, all order lines in the parcel are moved.



22
23
24
# File 'lib/zippendo/models/split_shipment_request.rb', line 22

def order_line_ids
  @order_line_ids
end

#parcel_idObject

Parcel whose order lines are split into a new shipment.



19
20
21
# File 'lib/zippendo/models/split_shipment_request.rb', line 19

def parcel_id
  @parcel_id
end

#product_idObject

Carrier product for the new shipment. Copied from the original if omitted.



28
29
30
# File 'lib/zippendo/models/split_shipment_request.rb', line 28

def product_id
  @product_id
end

#referenceObject

Reference for the new shipment. Defaults to the original reference with a suffix.



37
38
39
# File 'lib/zippendo/models/split_shipment_request.rb', line 37

def reference
  @reference
end

#servicesObject

Service codes for the new shipment. Copied from the original if omitted.



31
32
33
# File 'lib/zippendo/models/split_shipment_request.rb', line 31

def services
  @services
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/zippendo/models/split_shipment_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/zippendo/models/split_shipment_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/zippendo/models/split_shipment_request.rb', line 40

def self.attribute_map
  {
    :'parcel_id' => :'parcelId',
    :'order_line_ids' => :'orderLineIds',
    :'carrier_id' => :'carrierId',
    :'product_id' => :'productId',
    :'services' => :'services',
    :'additional_parameters' => :'additionalParameters',
    :'reference' => :'reference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zippendo/models/split_shipment_request.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/zippendo/models/split_shipment_request.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/zippendo/models/split_shipment_request.rb', line 63

def self.openapi_types
  {
    :'parcel_id' => :'String',
    :'order_line_ids' => :'Array<String>',
    :'carrier_id' => :'String',
    :'product_id' => :'String',
    :'services' => :'Array<String>',
    :'additional_parameters' => :'Hash<String, Object>',
    :'reference' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zippendo/models/split_shipment_request.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      parcel_id == o.parcel_id &&
      order_line_ids == o.order_line_ids &&
      carrier_id == o.carrier_id &&
      product_id == o.product_id &&
      services == o.services &&
      additional_parameters == o.additional_parameters &&
      reference == o.reference
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/zippendo/models/split_shipment_request.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/zippendo/models/split_shipment_request.rb', line 186

def hash
  [parcel_id, order_line_ids, carrier_id, product_id, services, additional_parameters, reference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
# File 'lib/zippendo/models/split_shipment_request.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @parcel_id.nil?
    invalid_properties.push('invalid value for "parcel_id", parcel_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zippendo/models/split_shipment_request.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
# File 'lib/zippendo/models/split_shipment_request.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @parcel_id.nil?
  true
end