Class: Zippendo::SystemApi
- Inherits:
-
Object
- Object
- Zippendo::SystemApi
- Defined in:
- lib/zippendo/api/system_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#health_check(opts = {}) ⇒ HealthCheck200Response
Health check Return the service health status, current timestamp, and version.
-
#health_check_with_http_info(opts = {}) ⇒ Array<(HealthCheck200Response, Integer, Hash)>
Health check Return the service health status, current timestamp, and version.
-
#initialize(api_client = ApiClient.default) ⇒ SystemApi
constructor
A new instance of SystemApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/system_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#health_check(opts = {}) ⇒ HealthCheck200Response
Health check Return the service health status, current timestamp, and version.
26 27 28 29 |
# File 'lib/zippendo/api/system_api.rb', line 26 def health_check(opts = {}) data, _status_code, _headers = health_check_with_http_info(opts) data end |
#health_check_with_http_info(opts = {}) ⇒ Array<(HealthCheck200Response, Integer, Hash)>
Health check Return the service health status, current timestamp, and version.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zippendo/api/system_api.rb', line 35 def health_check_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SystemApi.health_check ...' end # resource path local_var_path = '/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'HealthCheck200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SystemApi.health_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SystemApi#health_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |