Class: Zippendo::TokensApi
- Inherits:
-
Object
- Object
- Zippendo::TokensApi
- Defined in:
- lib/zippendo/api/tokens_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_api_token(org_id, create_api_token_request, opts = {}) ⇒ CreateApiToken201Response
Create API keys Creates a new API token for the specified organization.
-
#create_api_token_with_http_info(org_id, create_api_token_request, opts = {}) ⇒ Array<(CreateApiToken201Response, Integer, Hash)>
Create API keys Creates a new API token for the specified organization.
-
#get_api_token(org_id, token_id, opts = {}) ⇒ ListApiTokens200ResponseDataInner
Get API keys Returns metadata for a specific API token.
-
#get_api_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(ListApiTokens200ResponseDataInner, Integer, Hash)>
Get API keys Returns metadata for a specific API token.
-
#initialize(api_client = ApiClient.default) ⇒ TokensApi
constructor
A new instance of TokensApi.
-
#list_api_tokens(org_id, opts = {}) ⇒ ListApiTokens200Response
List API keys Returns a paginated list of API tokens belonging to the specified organization.
-
#list_api_tokens_with_http_info(org_id, opts = {}) ⇒ Array<(ListApiTokens200Response, Integer, Hash)>
List API keys Returns a paginated list of API tokens belonging to the specified organization.
-
#revoke_api_token(org_id, token_id, opts = {}) ⇒ RevokeApiToken200Response
Revoke API keys Revokes and deletes an API token.
-
#revoke_api_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(RevokeApiToken200Response, Integer, Hash)>
Revoke API keys Revokes and deletes an API token.
-
#update_api_token(org_id, token_id, update_api_token_request, opts = {}) ⇒ ListApiTokens200ResponseDataInner
Update API keys Updates the name of an API token.
-
#update_api_token_with_http_info(org_id, token_id, update_api_token_request, opts = {}) ⇒ Array<(ListApiTokens200ResponseDataInner, Integer, Hash)>
Update API keys Updates the name of an API token.
-
#verify_api_token(verify_api_token_request, opts = {}) ⇒ VerifyApiToken200Response
Verify API keys Verifies whether an API token is valid and returns its metadata.
-
#verify_api_token_with_http_info(verify_api_token_request, opts = {}) ⇒ Array<(VerifyApiToken200Response, Integer, Hash)>
Verify API keys Verifies whether an API token is valid and returns its metadata.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/tokens_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_api_token(org_id, create_api_token_request, opts = {}) ⇒ CreateApiToken201Response
Create API keys Creates a new API token for the specified organization. The full token is only shown once.
28 29 30 31 |
# File 'lib/zippendo/api/tokens_api.rb', line 28 def create_api_token(org_id, create_api_token_request, opts = {}) data, _status_code, _headers = create_api_token_with_http_info(org_id, create_api_token_request, opts) data end |
#create_api_token_with_http_info(org_id, create_api_token_request, opts = {}) ⇒ Array<(CreateApiToken201Response, Integer, Hash)>
Create API keys Creates a new API token for the specified organization. The full token is only shown once.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zippendo/api/tokens_api.rb', line 39 def create_api_token_with_http_info(org_id, create_api_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.create_api_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.create_api_token" end # verify the required parameter 'create_api_token_request' is set if @api_client.config.client_side_validation && create_api_token_request.nil? fail ArgumentError, "Missing the required parameter 'create_api_token_request' when calling TokensApi.create_api_token" end # resource path local_var_path = '/orgs/{orgId}/api-tokens'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_api_token_request) # return_type return_type = opts[:debug_return_type] || 'CreateApiToken201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.create_api_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#create_api_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_api_token(org_id, token_id, opts = {}) ⇒ ListApiTokens200ResponseDataInner
Get API keys Returns metadata for a specific API token. The token secret is never returned.
102 103 104 105 |
# File 'lib/zippendo/api/tokens_api.rb', line 102 def get_api_token(org_id, token_id, opts = {}) data, _status_code, _headers = get_api_token_with_http_info(org_id, token_id, opts) data end |
#get_api_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(ListApiTokens200ResponseDataInner, Integer, Hash)>
Get API keys Returns metadata for a specific API token. The token secret is never returned.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zippendo/api/tokens_api.rb', line 113 def get_api_token_with_http_info(org_id, token_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.get_api_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.get_api_token" end # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.get_api_token" end # resource path local_var_path = '/orgs/{orgId}/api-tokens/{tokenId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{tokenId}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApiTokens200ResponseDataInner' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.get_api_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#get_api_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_api_tokens(org_id, opts = {}) ⇒ ListApiTokens200Response
List API keys Returns a paginated list of API tokens belonging to the specified organization.
172 173 174 175 |
# File 'lib/zippendo/api/tokens_api.rb', line 172 def list_api_tokens(org_id, opts = {}) data, _status_code, _headers = list_api_tokens_with_http_info(org_id, opts) data end |
#list_api_tokens_with_http_info(org_id, opts = {}) ⇒ Array<(ListApiTokens200Response, Integer, Hash)>
List API keys Returns a paginated list of API tokens belonging to the specified organization.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/zippendo/api/tokens_api.rb', line 184 def list_api_tokens_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.list_api_tokens ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.list_api_tokens" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling TokensApi.list_api_tokens, must be smaller than or equal to 9007199254740991.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling TokensApi.list_api_tokens, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TokensApi.list_api_tokens, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TokensApi.list_api_tokens, must be greater than or equal to 1.' end # resource path local_var_path = '/orgs/{orgId}/api-tokens'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApiTokens200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.list_api_tokens", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#list_api_tokens\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_api_token(org_id, token_id, opts = {}) ⇒ RevokeApiToken200Response
Revoke API keys Revokes and deletes an API token.
256 257 258 259 |
# File 'lib/zippendo/api/tokens_api.rb', line 256 def revoke_api_token(org_id, token_id, opts = {}) data, _status_code, _headers = revoke_api_token_with_http_info(org_id, token_id, opts) data end |
#revoke_api_token_with_http_info(org_id, token_id, opts = {}) ⇒ Array<(RevokeApiToken200Response, Integer, Hash)>
Revoke API keys Revokes and deletes an API token.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/zippendo/api/tokens_api.rb', line 267 def revoke_api_token_with_http_info(org_id, token_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.revoke_api_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.revoke_api_token" end # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.revoke_api_token" end # resource path local_var_path = '/orgs/{orgId}/api-tokens/{tokenId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{tokenId}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RevokeApiToken200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.revoke_api_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#revoke_api_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_api_token(org_id, token_id, update_api_token_request, opts = {}) ⇒ ListApiTokens200ResponseDataInner
Update API keys Updates the name of an API token.
326 327 328 329 |
# File 'lib/zippendo/api/tokens_api.rb', line 326 def update_api_token(org_id, token_id, update_api_token_request, opts = {}) data, _status_code, _headers = update_api_token_with_http_info(org_id, token_id, update_api_token_request, opts) data end |
#update_api_token_with_http_info(org_id, token_id, update_api_token_request, opts = {}) ⇒ Array<(ListApiTokens200ResponseDataInner, Integer, Hash)>
Update API keys Updates the name of an API token.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/zippendo/api/tokens_api.rb', line 338 def update_api_token_with_http_info(org_id, token_id, update_api_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.update_api_token ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling TokensApi.update_api_token" end # verify the required parameter 'token_id' is set if @api_client.config.client_side_validation && token_id.nil? fail ArgumentError, "Missing the required parameter 'token_id' when calling TokensApi.update_api_token" end # verify the required parameter 'update_api_token_request' is set if @api_client.config.client_side_validation && update_api_token_request.nil? fail ArgumentError, "Missing the required parameter 'update_api_token_request' when calling TokensApi.update_api_token" end # resource path local_var_path = '/orgs/{orgId}/api-tokens/{tokenId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{tokenId}', CGI.escape(token_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_api_token_request) # return_type return_type = opts[:debug_return_type] || 'ListApiTokens200ResponseDataInner' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.update_api_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#update_api_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_api_token(verify_api_token_request, opts = {}) ⇒ VerifyApiToken200Response
Verify API keys Verifies whether an API token is valid and returns its metadata.
404 405 406 407 |
# File 'lib/zippendo/api/tokens_api.rb', line 404 def verify_api_token(verify_api_token_request, opts = {}) data, _status_code, _headers = verify_api_token_with_http_info(verify_api_token_request, opts) data end |
#verify_api_token_with_http_info(verify_api_token_request, opts = {}) ⇒ Array<(VerifyApiToken200Response, Integer, Hash)>
Verify API keys Verifies whether an API token is valid and returns its metadata.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/zippendo/api/tokens_api.rb', line 414 def verify_api_token_with_http_info(verify_api_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.verify_api_token ...' end # verify the required parameter 'verify_api_token_request' is set if @api_client.config.client_side_validation && verify_api_token_request.nil? fail ArgumentError, "Missing the required parameter 'verify_api_token_request' when calling TokensApi.verify_api_token" end # resource path local_var_path = '/api-tokens/verify' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(verify_api_token_request) # return_type return_type = opts[:debug_return_type] || 'VerifyApiToken200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TokensApi.verify_api_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#verify_api_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |