Class: Zippendo::UpdateOrderRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/update_order_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateOrderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zippendo/models/update_order_request.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'order_number')
    self.order_number = attributes[:'order_number']
  end

  if attributes.key?(:'customer_name')
    self.customer_name = attributes[:'customer_name']
  end

  if attributes.key?(:'customer_email')
    self.customer_email = attributes[:'customer_email']
  end

  if attributes.key?(:'shipping_address')
    self.shipping_address = attributes[:'shipping_address']
  end

  if attributes.key?(:'order_lines')
    if (value = attributes[:'order_lines']).is_a?(Array)
      self.order_lines = value
    end
  end

  if attributes.key?(:'subtotal_amount')
    self.subtotal_amount = attributes[:'subtotal_amount']
  end

  if attributes.key?(:'total_amount')
    self.total_amount = attributes[:'total_amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'shipping_rule_id')
    self.shipping_rule_id = attributes[:'shipping_rule_id']
  end
end

Instance Attribute Details

#currencyObject

ISO 4217 currency code.



39
40
41
# File 'lib/zippendo/models/update_order_request.rb', line 39

def currency
  @currency
end

#customer_emailObject

Customer email address.



25
26
27
# File 'lib/zippendo/models/update_order_request.rb', line 25

def customer_email
  @customer_email
end

#customer_nameObject

Customer full name.



22
23
24
# File 'lib/zippendo/models/update_order_request.rb', line 22

def customer_name
  @customer_name
end

#notesObject

Free-form internal notes.



42
43
44
# File 'lib/zippendo/models/update_order_request.rb', line 42

def notes
  @notes
end

#order_linesObject

Line items in the order.



30
31
32
# File 'lib/zippendo/models/update_order_request.rb', line 30

def order_lines
  @order_lines
end

#order_numberObject

Human-readable order number.



19
20
21
# File 'lib/zippendo/models/update_order_request.rb', line 19

def order_number
  @order_number
end

#shipping_addressObject

Returns the value of attribute shipping_address.



27
28
29
# File 'lib/zippendo/models/update_order_request.rb', line 27

def shipping_address
  @shipping_address
end

#shipping_rule_idObject

ID of the shipping rule to apply.



48
49
50
# File 'lib/zippendo/models/update_order_request.rb', line 48

def shipping_rule_id
  @shipping_rule_id
end

#statusObject

Order fulfilment status derived from its shipments.



45
46
47
# File 'lib/zippendo/models/update_order_request.rb', line 45

def status
  @status
end

#subtotal_amountObject

Order subtotal before shipping and tax.



33
34
35
# File 'lib/zippendo/models/update_order_request.rb', line 33

def subtotal_amount
  @subtotal_amount
end

#total_amountObject

Order grand total.



36
37
38
# File 'lib/zippendo/models/update_order_request.rb', line 36

def total_amount
  @total_amount
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



90
91
92
# File 'lib/zippendo/models/update_order_request.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/zippendo/models/update_order_request.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/zippendo/models/update_order_request.rb', line 73

def self.attribute_map
  {
    :'order_number' => :'orderNumber',
    :'customer_name' => :'customerName',
    :'customer_email' => :'customerEmail',
    :'shipping_address' => :'shippingAddress',
    :'order_lines' => :'orderLines',
    :'subtotal_amount' => :'subtotalAmount',
    :'total_amount' => :'totalAmount',
    :'currency' => :'currency',
    :'notes' => :'notes',
    :'status' => :'status',
    :'shipping_rule_id' => :'shippingRuleId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/zippendo/models/update_order_request.rb', line 362

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zippendo/models/update_order_request.rb', line 117

def self.openapi_nullable
  Set.new([
    :'customer_name',
    :'customer_email',
    :'shipping_address',
    :'subtotal_amount',
    :'total_amount',
    :'currency',
    :'notes',
    :'shipping_rule_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zippendo/models/update_order_request.rb', line 100

def self.openapi_types
  {
    :'order_number' => :'String',
    :'customer_name' => :'String',
    :'customer_email' => :'String',
    :'shipping_address' => :'CreateOrderRequestShippingAddress',
    :'order_lines' => :'Array<CreateOrderRequestOrderLinesInner>',
    :'subtotal_amount' => :'Float',
    :'total_amount' => :'Float',
    :'currency' => :'String',
    :'notes' => :'String',
    :'status' => :'String',
    :'shipping_rule_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/zippendo/models/update_order_request.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      order_number == o.order_number &&
      customer_name == o.customer_name &&
      customer_email == o.customer_email &&
      shipping_address == o.shipping_address &&
      order_lines == o.order_lines &&
      subtotal_amount == o.subtotal_amount &&
      total_amount == o.total_amount &&
      currency == o.currency &&
      notes == o.notes &&
      status == o.status &&
      shipping_rule_id == o.shipping_rule_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/zippendo/models/update_order_request.rb', line 349

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



355
356
357
# File 'lib/zippendo/models/update_order_request.rb', line 355

def hash
  [order_number, customer_name, customer_email, shipping_address, order_lines, subtotal_amount, total_amount, currency, notes, status, shipping_rule_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/zippendo/models/update_order_request.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@order_number.nil? && @order_number.to_s.length < 1
    invalid_properties.push('invalid value for "order_number", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/)
  if !@customer_email.nil? && @customer_email !~ pattern
    invalid_properties.push("invalid value for \"customer_email\", must conform to the pattern #{pattern}.")
  end

  if !@order_lines.nil? && @order_lines.length < 1
    invalid_properties.push('invalid value for "order_lines", number of items must be greater than or equal to 1.')
  end

  if !@subtotal_amount.nil? && @subtotal_amount < 0
    invalid_properties.push('invalid value for "subtotal_amount", must be greater than or equal to 0.')
  end

  if !@total_amount.nil? && @total_amount < 0
    invalid_properties.push('invalid value for "total_amount", must be greater than or equal to 0.')
  end

  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if !@currency.nil? && @currency.to_s.length < 3
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/zippendo/models/update_order_request.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/zippendo/models/update_order_request.rb', line 232

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@order_number.nil? && @order_number.to_s.length < 1
  return false if !@customer_email.nil? && @customer_email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/)
  return false if !@order_lines.nil? && @order_lines.length < 1
  return false if !@subtotal_amount.nil? && @subtotal_amount < 0
  return false if !@total_amount.nil? && @total_amount < 0
  return false if !@currency.nil? && @currency.to_s.length > 3
  return false if !@currency.nil? && @currency.to_s.length < 3
  status_validator = EnumAttributeValidator.new('String', ["pending", "processing", "partially_fulfilled", "fulfilled", "error", "cancelled"])
  return false unless status_validator.valid?(@status)
  true
end