Class: Zippendo::UpdateOrgBrandingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::UpdateOrgBrandingRequest
- Defined in:
- lib/zippendo/models/update_org_branding_request.rb
Instance Attribute Summary collapse
-
#primary_color ⇒ Object
Primary brand color (hex) — tints the document title and table headers.
-
#secondary_color ⇒ Object
Secondary brand color (hex) — tints the subtitle, section headings, and totals accent.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrgBrandingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrgBrandingRequest
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrgBrandingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrgBrandingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'primary_color') self.primary_color = attributes[:'primary_color'] end if attributes.key?(:'secondary_color') self.secondary_color = attributes[:'secondary_color'] end end |
Instance Attribute Details
#primary_color ⇒ Object
Primary brand color (hex) — tints the document title and table headers
19 20 21 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 19 def primary_color @primary_color end |
#secondary_color ⇒ Object
Secondary brand color (hex) — tints the subtitle, section headings, and totals accent
22 23 24 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 22 def secondary_color @secondary_color end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 25 def self.attribute_map { :'primary_color' => :'primaryColor', :'secondary_color' => :'secondaryColor' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 55 56 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 51 def self.openapi_nullable Set.new([ :'primary_color', :'secondary_color' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 43 def self.openapi_types { :'primary_color' => :'String', :'secondary_color' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && primary_color == o.primary_color && secondary_color == o.secondary_color end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 149 def hash [primary_color, secondary_color].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^#[0-9a-fA-F]{6}$/) if !@primary_color.nil? && @primary_color !~ pattern invalid_properties.push("invalid value for \"primary_color\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^#[0-9a-fA-F]{6}$/) if !@secondary_color.nil? && @secondary_color !~ pattern invalid_properties.push("invalid value for \"secondary_color\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
103 104 105 106 107 108 |
# File 'lib/zippendo/models/update_org_branding_request.rb', line 103 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@primary_color.nil? && @primary_color !~ Regexp.new(/^#[0-9a-fA-F]{6}$/) return false if !@secondary_color.nil? && @secondary_color !~ Regexp.new(/^#[0-9a-fA-F]{6}$/) true end |