Class: Zippendo::UpdateOrgRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/update_org_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateOrgRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zippendo/models/update_org_request.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrgRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrgRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'vat_number')
    self.vat_number = attributes[:'vat_number']
  end

  if attributes.key?(:'overage_enabled')
    self.overage_enabled = attributes[:'overage_enabled']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'billing_email')
    self.billing_email = attributes[:'billing_email']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'address_line1')
    self.address_line1 = attributes[:'address_line1']
  end

  if attributes.key?(:'address_line2')
    self.address_line2 = attributes[:'address_line2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'customs')
    if (value = attributes[:'customs']).is_a?(Hash)
      self.customs = value
    end
  end
end

Instance Attribute Details

#address_line1Object

Address line 1



46
47
48
# File 'lib/zippendo/models/update_org_request.rb', line 46

def address_line1
  @address_line1
end

#address_line2Object

Address line 2



49
50
51
# File 'lib/zippendo/models/update_org_request.rb', line 49

def address_line2
  @address_line2
end

#billing_emailObject

Billing email for invoices



40
41
42
# File 'lib/zippendo/models/update_org_request.rb', line 40

def billing_email
  @billing_email
end

#cityObject

City



52
53
54
# File 'lib/zippendo/models/update_org_request.rb', line 52

def city
  @city
end

#company_nameObject

Legal company name



43
44
45
# File 'lib/zippendo/models/update_org_request.rb', line 43

def company_name
  @company_name
end

#countryObject

Country (ISO 3166-1 alpha-2 code)



58
59
60
# File 'lib/zippendo/models/update_org_request.rb', line 58

def country
  @country
end

#currencyObject

Billing currency (ISO 4217 code)



28
29
30
# File 'lib/zippendo/models/update_org_request.rb', line 28

def currency
  @currency
end

#customsObject

Organization-wide customs identifiers (EORI, IOSS, VOEC, etc.); null clears all



61
62
63
# File 'lib/zippendo/models/update_org_request.rb', line 61

def customs
  @customs
end

#descriptionObject

Organization description



25
26
27
# File 'lib/zippendo/models/update_org_request.rb', line 25

def description
  @description
end

#nameObject

Organization name



19
20
21
# File 'lib/zippendo/models/update_org_request.rb', line 19

def name
  @name
end

#overage_enabledObject

Allow shipments beyond plan limit (overage charges apply)



34
35
36
# File 'lib/zippendo/models/update_org_request.rb', line 34

def overage_enabled
  @overage_enabled
end

#phoneObject

Billing/contact phone number



37
38
39
# File 'lib/zippendo/models/update_org_request.rb', line 37

def phone
  @phone
end

#postal_codeObject

Postal code



55
56
57
# File 'lib/zippendo/models/update_org_request.rb', line 55

def postal_code
  @postal_code
end

#slugObject

Organization slug



22
23
24
# File 'lib/zippendo/models/update_org_request.rb', line 22

def slug
  @slug
end

#vat_numberObject

Company VAT/tax ID for invoices



31
32
33
# File 'lib/zippendo/models/update_org_request.rb', line 31

def vat_number
  @vat_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



107
108
109
# File 'lib/zippendo/models/update_org_request.rb', line 107

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/zippendo/models/update_org_request.rb', line 112

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/zippendo/models/update_org_request.rb', line 86

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'description' => :'description',
    :'currency' => :'currency',
    :'vat_number' => :'vatNumber',
    :'overage_enabled' => :'overageEnabled',
    :'phone' => :'phone',
    :'billing_email' => :'billingEmail',
    :'company_name' => :'companyName',
    :'address_line1' => :'addressLine1',
    :'address_line2' => :'addressLine2',
    :'city' => :'city',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'customs' => :'customs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/zippendo/models/update_org_request.rb', line 388

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zippendo/models/update_org_request.rb', line 138

def self.openapi_nullable
  Set.new([
    :'vat_number',
    :'phone',
    :'billing_email',
    :'company_name',
    :'address_line1',
    :'address_line2',
    :'city',
    :'postal_code',
    :'country',
    :'customs'
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/zippendo/models/update_org_request.rb', line 117

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'description' => :'String',
    :'currency' => :'String',
    :'vat_number' => :'String',
    :'overage_enabled' => :'Boolean',
    :'phone' => :'String',
    :'billing_email' => :'String',
    :'company_name' => :'String',
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'city' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'customs' => :'Hash<String, String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/zippendo/models/update_org_request.rb', line 353

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      description == o.description &&
      currency == o.currency &&
      vat_number == o.vat_number &&
      overage_enabled == o.overage_enabled &&
      phone == o.phone &&
      billing_email == o.billing_email &&
      company_name == o.company_name &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      city == o.city &&
      postal_code == o.postal_code &&
      country == o.country &&
      customs == o.customs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


375
376
377
# File 'lib/zippendo/models/update_org_request.rb', line 375

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



381
382
383
# File 'lib/zippendo/models/update_org_request.rb', line 381

def hash
  [name, slug, description, currency, vat_number, overage_enabled, phone, billing_email, company_name, address_line1, address_line2, city, postal_code, country, customs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zippendo/models/update_org_request.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@slug.nil? && @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-z0-9-]+$/)
  if !@slug.nil? && @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if !@phone.nil? && @phone.to_s.length > 32
    invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 32.')
  end

  pattern = Regexp.new(/^\+?[\d\s()-]{4,31}$/)
  if !@phone.nil? && @phone !~ pattern
    invalid_properties.push("invalid value for \"phone\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/)
  if !@billing_email.nil? && @billing_email !~ pattern
    invalid_properties.push("invalid value for \"billing_email\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/zippendo/models/update_org_request.rb', line 410

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/zippendo/models/update_org_request.rb', line 269

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@slug.nil? && @slug.to_s.length < 1
  return false if !@slug.nil? && @slug !~ Regexp.new(/^[a-z0-9-]+$/)
  currency_validator = EnumAttributeValidator.new('String', ["DKK", "EUR", "USD", "GBP", "SEK", "NOK"])
  return false unless currency_validator.valid?(@currency)
  return false if !@phone.nil? && @phone.to_s.length > 32
  return false if !@phone.nil? && @phone !~ Regexp.new(/^\+?[\d\s()-]{4,31}$/)
  return false if !@billing_email.nil? && @billing_email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/)
  true
end