Class: Zippendo::UpdateOrgWebhookRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::UpdateOrgWebhookRequest
- Defined in:
- lib/zippendo/models/update_org_webhook_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#brand_id ⇒ Object
Brand this record is assigned to; null (or omitted outside a brand session) keeps it organization-wide.
-
#events ⇒ Object
Events to subscribe to.
-
#is_active ⇒ Object
Whether the webhook is active.
-
#name ⇒ Object
Human-readable webhook name.
-
#url ⇒ Object
Webhook endpoint URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrgWebhookRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrgWebhookRequest
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrgWebhookRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrgWebhookRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'brand_id') self.brand_id = attributes[:'brand_id'] end end |
Instance Attribute Details
#brand_id ⇒ Object
Brand this record is assigned to; null (or omitted outside a brand session) keeps it organization-wide
31 32 33 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 31 def brand_id @brand_id end |
#events ⇒ Object
Events to subscribe to
25 26 27 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 25 def events @events end |
#is_active ⇒ Object
Whether the webhook is active
28 29 30 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 28 def is_active @is_active end |
#name ⇒ Object
Human-readable webhook name
19 20 21 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 19 def name @name end |
#url ⇒ Object
Webhook endpoint URL
22 23 24 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 56 def self.attribute_map { :'name' => :'name', :'url' => :'url', :'events' => :'events', :'is_active' => :'isActive', :'brand_id' => :'brandId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 88 def self.openapi_nullable Set.new([ :'brand_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 77 def self.openapi_types { :'name' => :'String', :'url' => :'String', :'events' => :'Array<String>', :'is_active' => :'Boolean', :'brand_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && url == o.url && events == o.events && is_active == o.is_active && brand_id == o.brand_id end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 216 def hash [name, url, events, is_active, brand_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@events.nil? && @events.length < 1 invalid_properties.push('invalid value for "events", number of items must be greater than or equal to 1.') end if !@brand_id.nil? && @brand_id.to_s.length < 1 invalid_properties.push('invalid value for "brand_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 165 166 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 100 return false if !@name.nil? && @name.to_s.length < 1 return false if !@events.nil? && @events.length < 1 return false if !@brand_id.nil? && @brand_id.to_s.length < 1 true end |