Class: Zippendo::VerifyApiToken200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zippendo/models/verify_api_token200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VerifyApiToken200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::VerifyApiToken200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::VerifyApiToken200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  else
    self.valid = nil
  end

  if attributes.key?(:'token_id')
    self.token_id = attributes[:'token_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'org_id')
    self.org_id = attributes[:'org_id']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end
end

Instance Attribute Details

#expires_atObject

Expiry timestamp (ISO 8601), null if it never expires



34
35
36
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 34

def expires_at
  @expires_at
end

#org_idObject

Organization identifier the token belongs to



28
29
30
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 28

def org_id
  @org_id
end

#scopesObject

Permission scopes granted by the token



31
32
33
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 31

def scopes
  @scopes
end

#token_idObject

Token identifier



22
23
24
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 22

def token_id
  @token_id
end

#user_idObject

User identifier the token belongs to



25
26
27
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 25

def user_id
  @user_id
end

#validObject

Whether the token is valid



19
20
21
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 19

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 37

def self.attribute_map
  {
    :'valid' => :'valid',
    :'token_id' => :'tokenId',
    :'user_id' => :'userId',
    :'org_id' => :'orgId',
    :'scopes' => :'scopes',
    :'expires_at' => :'expiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 180

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 71

def self.openapi_nullable
  Set.new([
    :'expires_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 59

def self.openapi_types
  {
    :'valid' => :'Boolean',
    :'token_id' => :'String',
    :'user_id' => :'String',
    :'org_id' => :'String',
    :'scopes' => :'Array<String>',
    :'expires_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
161
162
163
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      valid == o.valid &&
      token_id == o.token_id &&
      user_id == o.user_id &&
      org_id == o.org_id &&
      scopes == o.scopes &&
      expires_at == o.expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 173

def hash
  [valid, token_id, user_id, org_id, scopes, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @valid.nil?
    invalid_properties.push('invalid value for "valid", valid cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 202

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
140
# File 'lib/zippendo/models/verify_api_token200_response.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @valid.nil?
  true
end