Class: Zippendo::WebhooksApi
- Inherits:
-
Object
- Object
- Zippendo::WebhooksApi
- Defined in:
- lib/zippendo/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_org_webhook(org_id, create_org_webhook_request, opts = {}) ⇒ CreateOrgWebhook201Response
Create webhook Create a new webhook endpoint for an organization that receives event notifications.
-
#create_org_webhook_with_http_info(org_id, create_org_webhook_request, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Create webhook Create a new webhook endpoint for an organization that receives event notifications.
-
#delete_org_webhook(org_id, webhook_id, opts = {}) ⇒ DeleteOrgWebhook200Response
Delete webhook Permanently delete a webhook and all its delivery logs.
-
#delete_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(DeleteOrgWebhook200Response, Integer, Hash)>
Delete webhook Permanently delete a webhook and all its delivery logs.
-
#get_org_webhook(org_id, webhook_id, opts = {}) ⇒ CreateOrgWebhook201Response
Get webhook Get a specific webhook including its signing secret.
-
#get_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Get webhook Get a specific webhook including its signing secret.
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#list_org_webhook_deliveries(org_id, webhook_id, opts = {}) ⇒ ListOrgWebhookDeliveries200Response
List webhook deliveries List the delivery history for a specific webhook.
-
#list_org_webhook_deliveries_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(ListOrgWebhookDeliveries200Response, Integer, Hash)>
List webhook deliveries List the delivery history for a specific webhook.
-
#list_org_webhooks(org_id, opts = {}) ⇒ ListOrgWebhooks200Response
List webhooks List all webhooks belonging to an organization.
-
#list_org_webhooks_with_http_info(org_id, opts = {}) ⇒ Array<(ListOrgWebhooks200Response, Integer, Hash)>
List webhooks List all webhooks belonging to an organization.
-
#test_org_webhook(org_id, webhook_id, opts = {}) ⇒ TestOrgWebhook200Response
Test webhook Send a test ping event to the webhook endpoint to verify connectivity.
-
#test_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(TestOrgWebhook200Response, Integer, Hash)>
Test webhook Send a test ping event to the webhook endpoint to verify connectivity.
-
#update_org_webhook(org_id, webhook_id, update_org_webhook_request, opts = {}) ⇒ CreateOrgWebhook201Response
Update webhook Update the configuration of an existing webhook.
-
#update_org_webhook_with_http_info(org_id, webhook_id, update_org_webhook_request, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Update webhook Update the configuration of an existing webhook.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/zippendo/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_org_webhook(org_id, create_org_webhook_request, opts = {}) ⇒ CreateOrgWebhook201Response
Create webhook Create a new webhook endpoint for an organization that receives event notifications.
28 29 30 31 |
# File 'lib/zippendo/api/webhooks_api.rb', line 28 def create_org_webhook(org_id, create_org_webhook_request, opts = {}) data, _status_code, _headers = create_org_webhook_with_http_info(org_id, create_org_webhook_request, opts) data end |
#create_org_webhook_with_http_info(org_id, create_org_webhook_request, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Create webhook Create a new webhook endpoint for an organization that receives event notifications.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zippendo/api/webhooks_api.rb', line 39 def create_org_webhook_with_http_info(org_id, create_org_webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.create_org_webhook ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.create_org_webhook" end # verify the required parameter 'create_org_webhook_request' is set if @api_client.config.client_side_validation && create_org_webhook_request.nil? fail ArgumentError, "Missing the required parameter 'create_org_webhook_request' when calling WebhooksApi.create_org_webhook" end # resource path local_var_path = '/orgs/{orgId}/webhooks'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_org_webhook_request) # return_type return_type = opts[:debug_return_type] || 'CreateOrgWebhook201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.create_org_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#create_org_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_org_webhook(org_id, webhook_id, opts = {}) ⇒ DeleteOrgWebhook200Response
Delete webhook Permanently delete a webhook and all its delivery logs.
102 103 104 105 |
# File 'lib/zippendo/api/webhooks_api.rb', line 102 def delete_org_webhook(org_id, webhook_id, opts = {}) data, _status_code, _headers = delete_org_webhook_with_http_info(org_id, webhook_id, opts) data end |
#delete_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(DeleteOrgWebhook200Response, Integer, Hash)>
Delete webhook Permanently delete a webhook and all its delivery logs.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zippendo/api/webhooks_api.rb', line 113 def delete_org_webhook_with_http_info(org_id, webhook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.delete_org_webhook ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.delete_org_webhook" end # verify the required parameter 'webhook_id' is set if @api_client.config.client_side_validation && webhook_id.nil? fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.delete_org_webhook" end # resource path local_var_path = '/orgs/{orgId}/webhooks/{webhookId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{webhookId}', CGI.escape(webhook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteOrgWebhook200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.delete_org_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#delete_org_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_org_webhook(org_id, webhook_id, opts = {}) ⇒ CreateOrgWebhook201Response
Get webhook Get a specific webhook including its signing secret.
171 172 173 174 |
# File 'lib/zippendo/api/webhooks_api.rb', line 171 def get_org_webhook(org_id, webhook_id, opts = {}) data, _status_code, _headers = get_org_webhook_with_http_info(org_id, webhook_id, opts) data end |
#get_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Get webhook Get a specific webhook including its signing secret.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/zippendo/api/webhooks_api.rb', line 182 def get_org_webhook_with_http_info(org_id, webhook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.get_org_webhook ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.get_org_webhook" end # verify the required parameter 'webhook_id' is set if @api_client.config.client_side_validation && webhook_id.nil? fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.get_org_webhook" end # resource path local_var_path = '/orgs/{orgId}/webhooks/{webhookId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{webhookId}', CGI.escape(webhook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CreateOrgWebhook201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.get_org_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#get_org_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_org_webhook_deliveries(org_id, webhook_id, opts = {}) ⇒ ListOrgWebhookDeliveries200Response
List webhook deliveries List the delivery history for a specific webhook.
242 243 244 245 |
# File 'lib/zippendo/api/webhooks_api.rb', line 242 def list_org_webhook_deliveries(org_id, webhook_id, opts = {}) data, _status_code, _headers = list_org_webhook_deliveries_with_http_info(org_id, webhook_id, opts) data end |
#list_org_webhook_deliveries_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(ListOrgWebhookDeliveries200Response, Integer, Hash)>
List webhook deliveries List the delivery history for a specific webhook.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/zippendo/api/webhooks_api.rb', line 255 def list_org_webhook_deliveries_with_http_info(org_id, webhook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.list_org_webhook_deliveries ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.list_org_webhook_deliveries" end # verify the required parameter 'webhook_id' is set if @api_client.config.client_side_validation && webhook_id.nil? fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.list_org_webhook_deliveries" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WebhooksApi.list_org_webhook_deliveries, must be smaller than or equal to 9007199254740991.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WebhooksApi.list_org_webhook_deliveries, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.list_org_webhook_deliveries, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.list_org_webhook_deliveries, must be greater than or equal to 1.' end # resource path local_var_path = '/orgs/{orgId}/webhooks/{webhookId}/deliveries'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{webhookId}', CGI.escape(webhook_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListOrgWebhookDeliveries200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.list_org_webhook_deliveries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#list_org_webhook_deliveries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_org_webhooks(org_id, opts = {}) ⇒ ListOrgWebhooks200Response
List webhooks List all webhooks belonging to an organization.
332 333 334 335 |
# File 'lib/zippendo/api/webhooks_api.rb', line 332 def list_org_webhooks(org_id, opts = {}) data, _status_code, _headers = list_org_webhooks_with_http_info(org_id, opts) data end |
#list_org_webhooks_with_http_info(org_id, opts = {}) ⇒ Array<(ListOrgWebhooks200Response, Integer, Hash)>
List webhooks List all webhooks belonging to an organization.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/zippendo/api/webhooks_api.rb', line 344 def list_org_webhooks_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.list_org_webhooks ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.list_org_webhooks" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WebhooksApi.list_org_webhooks, must be smaller than or equal to 9007199254740991.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WebhooksApi.list_org_webhooks, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.list_org_webhooks, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.list_org_webhooks, must be greater than or equal to 1.' end # resource path local_var_path = '/orgs/{orgId}/webhooks'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListOrgWebhooks200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.list_org_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#list_org_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#test_org_webhook(org_id, webhook_id, opts = {}) ⇒ TestOrgWebhook200Response
Test webhook Send a test ping event to the webhook endpoint to verify connectivity.
416 417 418 419 |
# File 'lib/zippendo/api/webhooks_api.rb', line 416 def test_org_webhook(org_id, webhook_id, opts = {}) data, _status_code, _headers = test_org_webhook_with_http_info(org_id, webhook_id, opts) data end |
#test_org_webhook_with_http_info(org_id, webhook_id, opts = {}) ⇒ Array<(TestOrgWebhook200Response, Integer, Hash)>
Test webhook Send a test ping event to the webhook endpoint to verify connectivity.
427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/zippendo/api/webhooks_api.rb', line 427 def test_org_webhook_with_http_info(org_id, webhook_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.test_org_webhook ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.test_org_webhook" end # verify the required parameter 'webhook_id' is set if @api_client.config.client_side_validation && webhook_id.nil? fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.test_org_webhook" end # resource path local_var_path = '/orgs/{orgId}/webhooks/{webhookId}/test'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{webhookId}', CGI.escape(webhook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TestOrgWebhook200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.test_org_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#test_org_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_org_webhook(org_id, webhook_id, update_org_webhook_request, opts = {}) ⇒ CreateOrgWebhook201Response
Update webhook Update the configuration of an existing webhook.
486 487 488 489 |
# File 'lib/zippendo/api/webhooks_api.rb', line 486 def update_org_webhook(org_id, webhook_id, update_org_webhook_request, opts = {}) data, _status_code, _headers = update_org_webhook_with_http_info(org_id, webhook_id, update_org_webhook_request, opts) data end |
#update_org_webhook_with_http_info(org_id, webhook_id, update_org_webhook_request, opts = {}) ⇒ Array<(CreateOrgWebhook201Response, Integer, Hash)>
Update webhook Update the configuration of an existing webhook.
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'lib/zippendo/api/webhooks_api.rb', line 498 def update_org_webhook_with_http_info(org_id, webhook_id, update_org_webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.update_org_webhook ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling WebhooksApi.update_org_webhook" end # verify the required parameter 'webhook_id' is set if @api_client.config.client_side_validation && webhook_id.nil? fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.update_org_webhook" end # verify the required parameter 'update_org_webhook_request' is set if @api_client.config.client_side_validation && update_org_webhook_request.nil? fail ArgumentError, "Missing the required parameter 'update_org_webhook_request' when calling WebhooksApi.update_org_webhook" end # resource path local_var_path = '/orgs/{orgId}/webhooks/{webhookId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{webhookId}', CGI.escape(webhook_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_org_webhook_request) # return_type return_type = opts[:debug_return_type] || 'CreateOrgWebhook201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.update_org_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#update_org_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |