Class: Zippendo::AddressesApi
- Inherits:
-
Object
- Object
- Zippendo::AddressesApi
- Defined in:
- lib/zippendo/api/addresses_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_address(org_id, create_address_request, opts = {}) ⇒ ListAddresses200ResponseDataInner
Create address Creates a new sender, pickup or return address for the organization.
-
#create_address_with_http_info(org_id, create_address_request, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Create address Creates a new sender, pickup or return address for the organization.
-
#delete_address(org_id, address_id, opts = {}) ⇒ String
Delete address Deletes an address belonging to the organization.
-
#delete_address_with_http_info(org_id, address_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Delete address Deletes an address belonging to the organization.
-
#get_address(org_id, address_id, opts = {}) ⇒ ListAddresses200ResponseDataInner
Get address Returns a single address belonging to the organization, identified by its ID.
-
#get_address_with_http_info(org_id, address_id, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Get address Returns a single address belonging to the organization, identified by its ID.
-
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
constructor
A new instance of AddressesApi.
-
#list_addresses(org_id, opts = {}) ⇒ ListAddresses200Response
List addresses Returns a paginated list of addresses for the organization, optionally filtered by type.
-
#list_addresses_with_http_info(org_id, opts = {}) ⇒ Array<(ListAddresses200Response, Integer, Hash)>
List addresses Returns a paginated list of addresses for the organization, optionally filtered by type.
-
#update_address(org_id, address_id, update_address_request, opts = {}) ⇒ ListAddresses200ResponseDataInner
Update address Updates an existing address belonging to the organization.
-
#update_address_with_http_info(org_id, address_id, update_address_request, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Update address Updates an existing address belonging to the organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AddressesApi
Returns a new instance of AddressesApi.
19 20 21 |
# File 'lib/zippendo/api/addresses_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/addresses_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_address(org_id, create_address_request, opts = {}) ⇒ ListAddresses200ResponseDataInner
Create address Creates a new sender, pickup or return address for the organization.
28 29 30 31 |
# File 'lib/zippendo/api/addresses_api.rb', line 28 def create_address(org_id, create_address_request, opts = {}) data, _status_code, _headers = create_address_with_http_info(org_id, create_address_request, opts) data end |
#create_address_with_http_info(org_id, create_address_request, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Create address Creates a new sender, pickup or return address for the organization.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zippendo/api/addresses_api.rb', line 39 def create_address_with_http_info(org_id, create_address_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.create_address ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AddressesApi.create_address" end # verify the required parameter 'create_address_request' is set if @api_client.config.client_side_validation && create_address_request.nil? fail ArgumentError, "Missing the required parameter 'create_address_request' when calling AddressesApi.create_address" end # resource path local_var_path = '/orgs/{orgId}/addresses'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_address_request) # return_type return_type = opts[:debug_return_type] || 'ListAddresses200ResponseDataInner' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AddressesApi.create_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#create_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_address(org_id, address_id, opts = {}) ⇒ String
Delete address Deletes an address belonging to the organization.
102 103 104 105 |
# File 'lib/zippendo/api/addresses_api.rb', line 102 def delete_address(org_id, address_id, opts = {}) data, _status_code, _headers = delete_address_with_http_info(org_id, address_id, opts) data end |
#delete_address_with_http_info(org_id, address_id, opts = {}) ⇒ Array<(String, Integer, Hash)>
Delete address Deletes an address belonging to the organization.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zippendo/api/addresses_api.rb', line 113 def delete_address_with_http_info(org_id, address_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.delete_address ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AddressesApi.delete_address" end # verify the required parameter 'address_id' is set if @api_client.config.client_side_validation && address_id.nil? fail ArgumentError, "Missing the required parameter 'address_id' when calling AddressesApi.delete_address" end # resource path local_var_path = '/orgs/{orgId}/addresses/{addressId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{addressId}', CGI.escape(address_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AddressesApi.delete_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#delete_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_address(org_id, address_id, opts = {}) ⇒ ListAddresses200ResponseDataInner
Get address Returns a single address belonging to the organization, identified by its ID.
171 172 173 174 |
# File 'lib/zippendo/api/addresses_api.rb', line 171 def get_address(org_id, address_id, opts = {}) data, _status_code, _headers = get_address_with_http_info(org_id, address_id, opts) data end |
#get_address_with_http_info(org_id, address_id, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Get address Returns a single address belonging to the organization, identified by its ID.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/zippendo/api/addresses_api.rb', line 182 def get_address_with_http_info(org_id, address_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.get_address ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AddressesApi.get_address" end # verify the required parameter 'address_id' is set if @api_client.config.client_side_validation && address_id.nil? fail ArgumentError, "Missing the required parameter 'address_id' when calling AddressesApi.get_address" end # resource path local_var_path = '/orgs/{orgId}/addresses/{addressId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{addressId}', CGI.escape(address_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListAddresses200ResponseDataInner' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AddressesApi.get_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#get_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_addresses(org_id, opts = {}) ⇒ ListAddresses200Response
List addresses Returns a paginated list of addresses for the organization, optionally filtered by type.
242 243 244 245 |
# File 'lib/zippendo/api/addresses_api.rb', line 242 def list_addresses(org_id, opts = {}) data, _status_code, _headers = list_addresses_with_http_info(org_id, opts) data end |
#list_addresses_with_http_info(org_id, opts = {}) ⇒ Array<(ListAddresses200Response, Integer, Hash)>
List addresses Returns a paginated list of addresses for the organization, optionally filtered by type.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/zippendo/api/addresses_api.rb', line 255 def list_addresses_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.list_addresses ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AddressesApi.list_addresses" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 9007199254740991 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AddressesApi.list_addresses, must be smaller than or equal to 9007199254740991.' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AddressesApi.list_addresses, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AddressesApi.list_addresses, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AddressesApi.list_addresses, must be greater than or equal to 1.' end allowable_values = ["sender", "pickup", "return"] if @api_client.config.client_side_validation && opts[:'type'] && !allowable_values.include?(opts[:'type']) fail ArgumentError, "invalid value for \"type\", must be one of #{allowable_values}" end # resource path local_var_path = '/orgs/{orgId}/addresses'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListAddresses200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AddressesApi.list_addresses", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#list_addresses\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_address(org_id, address_id, update_address_request, opts = {}) ⇒ ListAddresses200ResponseDataInner
Update address Updates an existing address belonging to the organization.
333 334 335 336 |
# File 'lib/zippendo/api/addresses_api.rb', line 333 def update_address(org_id, address_id, update_address_request, opts = {}) data, _status_code, _headers = update_address_with_http_info(org_id, address_id, update_address_request, opts) data end |
#update_address_with_http_info(org_id, address_id, update_address_request, opts = {}) ⇒ Array<(ListAddresses200ResponseDataInner, Integer, Hash)>
Update address Updates an existing address belonging to the organization.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/zippendo/api/addresses_api.rb', line 345 def update_address_with_http_info(org_id, address_id, update_address_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AddressesApi.update_address ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling AddressesApi.update_address" end # verify the required parameter 'address_id' is set if @api_client.config.client_side_validation && address_id.nil? fail ArgumentError, "Missing the required parameter 'address_id' when calling AddressesApi.update_address" end # verify the required parameter 'update_address_request' is set if @api_client.config.client_side_validation && update_address_request.nil? fail ArgumentError, "Missing the required parameter 'update_address_request' when calling AddressesApi.update_address" end # resource path local_var_path = '/orgs/{orgId}/addresses/{addressId}'.sub('{orgId}', CGI.escape(org_id.to_s)).sub('{addressId}', CGI.escape(address_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_address_request) # return_type return_type = opts[:debug_return_type] || 'ListAddresses200ResponseDataInner' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AddressesApi.update_address", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AddressesApi#update_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |