Class: Zippendo::BatchSendShipments200ResponseSummary

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zippendo/models/batch_send_shipments200_response_summary.rb

Overview

Aggregate counts for the batch.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BatchSendShipments200ResponseSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::BatchSendShipments200ResponseSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::BatchSendShipments200ResponseSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'sent')
    self.sent = attributes[:'sent']
  else
    self.sent = nil
  end

  if attributes.key?(:'failed')
    self.failed = attributes[:'failed']
  else
    self.failed = nil
  end
end

Instance Attribute Details

#failedObject

How many failed.



26
27
28
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 26

def failed
  @failed
end

#sentObject

How many were successfully booked.



23
24
25
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 23

def sent
  @sent
end

#totalObject

Number of unique shipments processed.



20
21
22
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 20

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 29

def self.attribute_map
  {
    :'total' => :'total',
    :'sent' => :'sent',
    :'failed' => :'failed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 48

def self.openapi_types
  {
    :'total' => :'Integer',
    :'sent' => :'Integer',
    :'failed' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total == o.total &&
      sent == o.sent &&
      failed == o.failed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 229

def hash
  [total, sent, failed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @total > 9007199254740991
    invalid_properties.push('invalid value for "total", must be smaller than or equal to 9007199254740991.')
  end

  if @total < -9007199254740991
    invalid_properties.push('invalid value for "total", must be greater than or equal to -9007199254740991.')
  end

  if @sent.nil?
    invalid_properties.push('invalid value for "sent", sent cannot be nil.')
  end

  if @sent > 9007199254740991
    invalid_properties.push('invalid value for "sent", must be smaller than or equal to 9007199254740991.')
  end

  if @sent < -9007199254740991
    invalid_properties.push('invalid value for "sent", must be greater than or equal to -9007199254740991.')
  end

  if @failed.nil?
    invalid_properties.push('invalid value for "failed", failed cannot be nil.')
  end

  if @failed > 9007199254740991
    invalid_properties.push('invalid value for "failed", must be smaller than or equal to 9007199254740991.')
  end

  if @failed < -9007199254740991
    invalid_properties.push('invalid value for "failed", must be greater than or equal to -9007199254740991.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/zippendo/models/batch_send_shipments200_response_summary.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total.nil?
  return false if @total > 9007199254740991
  return false if @total < -9007199254740991
  return false if @sent.nil?
  return false if @sent > 9007199254740991
  return false if @sent < -9007199254740991
  return false if @failed.nil?
  return false if @failed > 9007199254740991
  return false if @failed < -9007199254740991
  true
end