Class: Zippendo::CarrierCatalogApi
- Inherits:
-
Object
- Object
- Zippendo::CarrierCatalogApi
- Defined in:
- lib/zippendo/api/carrier_catalog_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ CarrierCatalogApi
constructor
A new instance of CarrierCatalogApi.
-
#list_available_carriers(org_id, opts = {}) ⇒ Array<ListAvailableCarriers200ResponseInner>
List available carriers Returns the carriers available to connect, as supported by the carrier server.
-
#list_available_carriers_with_http_info(org_id, opts = {}) ⇒ Array<(Array<ListAvailableCarriers200ResponseInner>, Integer, Hash)>
List available carriers Returns the carriers available to connect, as supported by the carrier server.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CarrierCatalogApi
Returns a new instance of CarrierCatalogApi.
19 20 21 |
# File 'lib/zippendo/api/carrier_catalog_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/carrier_catalog_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_available_carriers(org_id, opts = {}) ⇒ Array<ListAvailableCarriers200ResponseInner>
List available carriers Returns the carriers available to connect, as supported by the carrier server.
27 28 29 30 |
# File 'lib/zippendo/api/carrier_catalog_api.rb', line 27 def list_available_carriers(org_id, opts = {}) data, _status_code, _headers = list_available_carriers_with_http_info(org_id, opts) data end |
#list_available_carriers_with_http_info(org_id, opts = {}) ⇒ Array<(Array<ListAvailableCarriers200ResponseInner>, Integer, Hash)>
List available carriers Returns the carriers available to connect, as supported by the carrier server.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zippendo/api/carrier_catalog_api.rb', line 37 def list_available_carriers_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CarrierCatalogApi.list_available_carriers ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling CarrierCatalogApi.list_available_carriers" end # resource path local_var_path = '/orgs/{orgId}/available-carriers'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ListAvailableCarriers200ResponseInner>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CarrierCatalogApi.list_available_carriers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CarrierCatalogApi#list_available_carriers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |