Class: Zippendo::CreateApiToken201Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateApiToken201Response
- Defined in:
- lib/zippendo/models/create_api_token201_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Creation timestamp (ISO 8601).
-
#expires_at ⇒ Object
Expiry timestamp (ISO 8601), null if it never expires.
-
#id ⇒ Object
Unique API token identifier.
-
#last_used_at ⇒ Object
Timestamp the token was last used (ISO 8601), null if never used.
-
#name ⇒ Object
Token name for identification.
-
#scopes ⇒ Object
Permission scopes granted by the token.
-
#token ⇒ Object
Full API token (only shown once).
-
#token_prefix ⇒ Object
First 12 chars of the token for identification.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApiToken201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateApiToken201Response
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateApiToken201Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateApiToken201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'token_prefix') self.token_prefix = attributes[:'token_prefix'] else self.token_prefix = nil end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end else self.scopes = nil end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] else self.last_used_at = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'token') self.token = attributes[:'token'] else self.token = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Creation timestamp (ISO 8601)
37 38 39 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 37 def created_at @created_at end |
#expires_at ⇒ Object
Expiry timestamp (ISO 8601), null if it never expires
34 35 36 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 34 def expires_at @expires_at end |
#id ⇒ Object
Unique API token identifier
19 20 21 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 19 def id @id end |
#last_used_at ⇒ Object
Timestamp the token was last used (ISO 8601), null if never used
31 32 33 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 31 def last_used_at @last_used_at end |
#name ⇒ Object
Token name for identification
22 23 24 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 22 def name @name end |
#scopes ⇒ Object
Permission scopes granted by the token
28 29 30 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 28 def scopes @scopes end |
#token ⇒ Object
Full API token (only shown once)
40 41 42 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 40 def token @token end |
#token_prefix ⇒ Object
First 12 chars of the token for identification
25 26 27 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 25 def token_prefix @token_prefix end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 43 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'token_prefix' => :'tokenPrefix', :'scopes' => :'scopes', :'last_used_at' => :'lastUsedAt', :'expires_at' => :'expiresAt', :'created_at' => :'createdAt', :'token' => :'token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 290 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 81 def self.openapi_nullable Set.new([ :'last_used_at', :'expires_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 67 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'token_prefix' => :'String', :'scopes' => :'Array<String>', :'last_used_at' => :'String', :'expires_at' => :'String', :'created_at' => :'String', :'token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && token_prefix == o.token_prefix && scopes == o.scopes && last_used_at == o.last_used_at && expires_at == o.expires_at && created_at == o.created_at && token == o.token end |
#eql?(o) ⇒ Boolean
277 278 279 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 277 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 283 def hash [id, name, token_prefix, scopes, last_used_at, expires_at, created_at, token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @token_prefix.nil? invalid_properties.push('invalid value for "token_prefix", token_prefix cannot be nil.') end if @scopes.nil? invalid_properties.push('invalid value for "scopes", scopes cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @token.nil? invalid_properties.push('invalid value for "token", token cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zippendo/models/create_api_token201_response.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @token_prefix.nil? return false if @scopes.nil? return false if @created_at.nil? return false if @token.nil? true end |