Class: Zippendo::CreateOrder201ResponseShippingAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateOrder201ResponseShippingAddress
- Defined in:
- lib/zippendo/models/create_order201_response_shipping_address.rb
Overview
Destination shipping address.
Instance Attribute Summary collapse
-
#address1 ⇒ Object
Street address line 1.
-
#address2 ⇒ Object
Street address line 2.
-
#attention ⇒ Object
Attention / care-of line.
-
#city ⇒ Object
City name.
-
#company ⇒ Object
Company name.
-
#country ⇒ Object
Country name.
-
#country_code ⇒ Object
ISO 3166-1 alpha-2 country code.
-
#email ⇒ Object
Recipient email address.
-
#name ⇒ Object
Recipient full name.
-
#phone ⇒ Object
Recipient phone number.
-
#postal_code ⇒ Object
Postal code.
-
#province ⇒ Object
Province or region name.
-
#province_code ⇒ Object
Province or region code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrder201ResponseShippingAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrder201ResponseShippingAddress
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateOrder201ResponseShippingAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateOrder201ResponseShippingAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'attention') self.attention = attributes[:'attention'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'address1') self.address1 = attributes[:'address1'] else self.address1 = nil end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'province') self.province = attributes[:'province'] end if attributes.key?(:'province_code') self.province_code = attributes[:'province_code'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] else self.postal_code = nil end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] else self.country_code = nil end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'email') self.email = attributes[:'email'] end end |
Instance Attribute Details
#address1 ⇒ Object
Street address line 1.
29 30 31 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 29 def address1 @address1 end |
#address2 ⇒ Object
Street address line 2.
32 33 34 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 32 def address2 @address2 end |
#attention ⇒ Object
Attention / care-of line.
23 24 25 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 23 def attention @attention end |
#city ⇒ Object
City name.
35 36 37 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 35 def city @city end |
#company ⇒ Object
Company name.
26 27 28 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 26 def company @company end |
#country ⇒ Object
Country name.
47 48 49 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 47 def country @country end |
#country_code ⇒ Object
ISO 3166-1 alpha-2 country code.
50 51 52 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 50 def country_code @country_code end |
#email ⇒ Object
Recipient email address.
56 57 58 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 56 def email @email end |
#name ⇒ Object
Recipient full name.
20 21 22 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 20 def name @name end |
#phone ⇒ Object
Recipient phone number.
53 54 55 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 53 def phone @phone end |
#postal_code ⇒ Object
Postal code.
44 45 46 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 44 def postal_code @postal_code end |
#province ⇒ Object
Province or region name.
38 39 40 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 38 def province @province end |
#province_code ⇒ Object
Province or region code.
41 42 43 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 41 def province_code @province_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 59 def self.attribute_map { :'name' => :'name', :'attention' => :'attention', :'company' => :'company', :'address1' => :'address1', :'address2' => :'address2', :'city' => :'city', :'province' => :'province', :'province_code' => :'provinceCode', :'postal_code' => :'postalCode', :'country' => :'country', :'country_code' => :'countryCode', :'phone' => :'phone', :'email' => :'email' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 395 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 107 def self.openapi_nullable Set.new([ :'attention', :'company', :'address2', :'province', :'province_code', :'country', :'phone', :'email' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 88 def self.openapi_types { :'name' => :'String', :'attention' => :'String', :'company' => :'String', :'address1' => :'String', :'address2' => :'String', :'city' => :'String', :'province' => :'String', :'province_code' => :'String', :'postal_code' => :'String', :'country' => :'String', :'country_code' => :'String', :'phone' => :'String', :'email' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 362 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && attention == o.attention && company == o.company && address1 == o.address1 && address2 == o.address2 && city == o.city && province == o.province && province_code == o.province_code && postal_code == o.postal_code && country == o.country && country_code == o.country_code && phone == o.phone && email == o.email end |
#eql?(o) ⇒ Boolean
382 383 384 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 382 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
388 389 390 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 388 def hash [name, attention, company, address1, address2, city, province, province_code, postal_code, country, country_code, phone, email].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 201 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @address1.nil? invalid_properties.push('invalid value for "address1", address1 cannot be nil.') end if @address1.to_s.length < 1 invalid_properties.push('invalid value for "address1", the character length must be greater than or equal to 1.') end if @city.nil? invalid_properties.push('invalid value for "city", city cannot be nil.') end if @city.to_s.length < 1 invalid_properties.push('invalid value for "city", the character length must be greater than or equal to 1.') end if @postal_code.nil? invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.') end if @postal_code.to_s.length < 1 invalid_properties.push('invalid value for "postal_code", the character length must be greater than or equal to 1.') end if @country_code.nil? invalid_properties.push('invalid value for "country_code", country_code cannot be nil.') end if @country_code.to_s.length > 2 invalid_properties.push('invalid value for "country_code", the character length must be smaller than or equal to 2.') end if @country_code.to_s.length < 2 invalid_properties.push('invalid value for "country_code", the character length must be greater than or equal to 2.') end pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) if !@email.nil? && @email !~ pattern invalid_properties.push("invalid value for \"email\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 417 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/zippendo/models/create_order201_response_shipping_address.rb', line 258 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @address1.nil? return false if @address1.to_s.length < 1 return false if @city.nil? return false if @city.to_s.length < 1 return false if @postal_code.nil? return false if @postal_code.to_s.length < 1 return false if @country_code.nil? return false if @country_code.to_s.length > 2 return false if @country_code.to_s.length < 2 return false if !@email.nil? && @email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) true end |