Class: Zippendo::CreateOrderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::CreateOrderRequest
- Defined in:
- lib/zippendo/models/create_order_request.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
ISO 4217 currency code.
-
#customer_email ⇒ Object
Customer email address.
-
#customer_name ⇒ Object
Customer full name.
-
#external_data ⇒ Object
Raw platform-specific payload for reference.
-
#external_id ⇒ Object
Identifier of the order in the source platform.
-
#notes ⇒ Object
Free-form internal notes.
-
#order_channel_id ⇒ Object
ID of the order channel this order belongs to.
-
#order_lines ⇒ Object
Line items in the order.
-
#order_number ⇒ Object
Human-readable order number.
-
#shipping_address ⇒ Object
Returns the value of attribute shipping_address.
-
#subtotal_amount ⇒ Object
Order subtotal before shipping and tax.
-
#total_amount ⇒ Object
Order grand total.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrderRequest
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zippendo/models/create_order_request.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::CreateOrderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::CreateOrderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'order_number') self.order_number = attributes[:'order_number'] else self.order_number = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'order_channel_id') self.order_channel_id = attributes[:'order_channel_id'] else self.order_channel_id = nil end if attributes.key?(:'customer_name') self.customer_name = attributes[:'customer_name'] end if attributes.key?(:'customer_email') self.customer_email = attributes[:'customer_email'] end if attributes.key?(:'shipping_address') self.shipping_address = attributes[:'shipping_address'] end if attributes.key?(:'order_lines') if (value = attributes[:'order_lines']).is_a?(Array) self.order_lines = value end else self.order_lines = nil end if attributes.key?(:'subtotal_amount') self.subtotal_amount = attributes[:'subtotal_amount'] end if attributes.key?(:'total_amount') self.total_amount = attributes[:'total_amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'external_data') if (value = attributes[:'external_data']).is_a?(Hash) self.external_data = value end end end |
Instance Attribute Details
#currency ⇒ Object
ISO 4217 currency code.
45 46 47 |
# File 'lib/zippendo/models/create_order_request.rb', line 45 def currency @currency end |
#customer_email ⇒ Object
Customer email address.
31 32 33 |
# File 'lib/zippendo/models/create_order_request.rb', line 31 def customer_email @customer_email end |
#customer_name ⇒ Object
Customer full name.
28 29 30 |
# File 'lib/zippendo/models/create_order_request.rb', line 28 def customer_name @customer_name end |
#external_data ⇒ Object
Raw platform-specific payload for reference.
51 52 53 |
# File 'lib/zippendo/models/create_order_request.rb', line 51 def external_data @external_data end |
#external_id ⇒ Object
Identifier of the order in the source platform.
22 23 24 |
# File 'lib/zippendo/models/create_order_request.rb', line 22 def external_id @external_id end |
#notes ⇒ Object
Free-form internal notes.
48 49 50 |
# File 'lib/zippendo/models/create_order_request.rb', line 48 def notes @notes end |
#order_channel_id ⇒ Object
ID of the order channel this order belongs to.
25 26 27 |
# File 'lib/zippendo/models/create_order_request.rb', line 25 def order_channel_id @order_channel_id end |
#order_lines ⇒ Object
Line items in the order.
36 37 38 |
# File 'lib/zippendo/models/create_order_request.rb', line 36 def order_lines @order_lines end |
#order_number ⇒ Object
Human-readable order number.
19 20 21 |
# File 'lib/zippendo/models/create_order_request.rb', line 19 def order_number @order_number end |
#shipping_address ⇒ Object
Returns the value of attribute shipping_address.
33 34 35 |
# File 'lib/zippendo/models/create_order_request.rb', line 33 def shipping_address @shipping_address end |
#subtotal_amount ⇒ Object
Order subtotal before shipping and tax.
39 40 41 |
# File 'lib/zippendo/models/create_order_request.rb', line 39 def subtotal_amount @subtotal_amount end |
#total_amount ⇒ Object
Order grand total.
42 43 44 |
# File 'lib/zippendo/models/create_order_request.rb', line 42 def total_amount @total_amount end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/zippendo/models/create_order_request.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/zippendo/models/create_order_request.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zippendo/models/create_order_request.rb', line 54 def self.attribute_map { :'order_number' => :'orderNumber', :'external_id' => :'externalId', :'order_channel_id' => :'orderChannelId', :'customer_name' => :'customerName', :'customer_email' => :'customerEmail', :'shipping_address' => :'shippingAddress', :'order_lines' => :'orderLines', :'subtotal_amount' => :'subtotalAmount', :'total_amount' => :'totalAmount', :'currency' => :'currency', :'notes' => :'notes', :'external_data' => :'externalData' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/zippendo/models/create_order_request.rb', line 372 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zippendo/models/create_order_request.rb', line 100 def self.openapi_nullable Set.new([ :'external_id', :'customer_name', :'customer_email', :'shipping_address', :'subtotal_amount', :'total_amount', :'currency', :'notes', :'external_data' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/zippendo/models/create_order_request.rb', line 82 def self.openapi_types { :'order_number' => :'String', :'external_id' => :'String', :'order_channel_id' => :'String', :'customer_name' => :'String', :'customer_email' => :'String', :'shipping_address' => :'CreateOrderRequestShippingAddress', :'order_lines' => :'Array<CreateOrderRequestOrderLinesInner>', :'subtotal_amount' => :'Float', :'total_amount' => :'Float', :'currency' => :'String', :'notes' => :'String', :'external_data' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/zippendo/models/create_order_request.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && order_number == o.order_number && external_id == o.external_id && order_channel_id == o.order_channel_id && customer_name == o.customer_name && customer_email == o.customer_email && shipping_address == o.shipping_address && order_lines == o.order_lines && subtotal_amount == o.subtotal_amount && total_amount == o.total_amount && currency == o.currency && notes == o.notes && external_data == o.external_data end |
#eql?(o) ⇒ Boolean
359 360 361 |
# File 'lib/zippendo/models/create_order_request.rb', line 359 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/zippendo/models/create_order_request.rb', line 365 def hash [order_number, external_id, order_channel_id, customer_name, customer_email, shipping_address, order_lines, subtotal_amount, total_amount, currency, notes, external_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/zippendo/models/create_order_request.rb', line 191 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @order_number.nil? invalid_properties.push('invalid value for "order_number", order_number cannot be nil.') end if @order_number.to_s.length < 1 invalid_properties.push('invalid value for "order_number", the character length must be greater than or equal to 1.') end if @order_channel_id.nil? invalid_properties.push('invalid value for "order_channel_id", order_channel_id cannot be nil.') end pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) if !@customer_email.nil? && @customer_email !~ pattern invalid_properties.push("invalid value for \"customer_email\", must conform to the pattern #{pattern}.") end if @order_lines.nil? invalid_properties.push('invalid value for "order_lines", order_lines cannot be nil.') end if @order_lines.length < 1 invalid_properties.push('invalid value for "order_lines", number of items must be greater than or equal to 1.') end if !@subtotal_amount.nil? && @subtotal_amount < 0 invalid_properties.push('invalid value for "subtotal_amount", must be greater than or equal to 0.') end if !@total_amount.nil? && @total_amount < 0 invalid_properties.push('invalid value for "total_amount", must be greater than or equal to 0.') end if !@currency.nil? && @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if !@currency.nil? && @currency.to_s.length < 3 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/zippendo/models/create_order_request.rb', line 394 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zippendo/models/create_order_request.rb', line 240 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @order_number.nil? return false if @order_number.to_s.length < 1 return false if @order_channel_id.nil? return false if !@customer_email.nil? && @customer_email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) return false if @order_lines.nil? return false if @order_lines.length < 1 return false if !@subtotal_amount.nil? && @subtotal_amount < 0 return false if !@total_amount.nil? && @total_amount < 0 return false if !@currency.nil? && @currency.to_s.length > 3 return false if !@currency.nil? && @currency.to_s.length < 3 true end |