Class: Zippendo::GetOrder200ResponseShipmentsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::GetOrder200ResponseShipmentsInner
- Defined in:
- lib/zippendo/models/get_order200_response_shipments_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#carrier_settings ⇒ Object
Returns the value of attribute carrier_settings.
-
#created_at ⇒ Object
Timestamp when the shipment was created.
-
#documents ⇒ Object
Documents (labels, customs forms) for this shipment.
-
#id ⇒ Object
Unique shipment identifier.
-
#reference ⇒ Object
Customer-facing shipment reference.
-
#service_point_id ⇒ Object
Selected carrier service point identifier.
-
#shipping_rule_id ⇒ Object
ID of the shipping rule used for this shipment.
-
#status ⇒ Object
Lifecycle status of the shipment.
-
#tracking ⇒ Object
Returns the value of attribute tracking.
-
#type ⇒ Object
Direction of the shipment relative to the organization.
-
#updated_at ⇒ Object
Timestamp when the shipment was last updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetOrder200ResponseShipmentsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetOrder200ResponseShipmentsInner
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::GetOrder200ResponseShipmentsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::GetOrder200ResponseShipmentsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'reference') self.reference = attributes[:'reference'] else self.reference = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'tracking') self.tracking = attributes[:'tracking'] end if attributes.key?(:'carrier_settings') self.carrier_settings = attributes[:'carrier_settings'] else self.carrier_settings = nil end if attributes.key?(:'service_point_id') self.service_point_id = attributes[:'service_point_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'shipping_rule_id') self.shipping_rule_id = attributes[:'shipping_rule_id'] end if attributes.key?(:'documents') if (value = attributes[:'documents']).is_a?(Array) self.documents = value end end end |
Instance Attribute Details
#carrier_settings ⇒ Object
Returns the value of attribute carrier_settings.
32 33 34 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 32 def carrier_settings @carrier_settings end |
#created_at ⇒ Object
Timestamp when the shipment was created.
38 39 40 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 38 def created_at @created_at end |
#documents ⇒ Object
Documents (labels, customs forms) for this shipment.
47 48 49 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 47 def documents @documents end |
#id ⇒ Object
Unique shipment identifier.
19 20 21 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 19 def id @id end |
#reference ⇒ Object
Customer-facing shipment reference.
22 23 24 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 22 def reference @reference end |
#service_point_id ⇒ Object
Selected carrier service point identifier.
35 36 37 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 35 def service_point_id @service_point_id end |
#shipping_rule_id ⇒ Object
ID of the shipping rule used for this shipment.
44 45 46 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 44 def shipping_rule_id @shipping_rule_id end |
#status ⇒ Object
Lifecycle status of the shipment.
25 26 27 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 25 def status @status end |
#tracking ⇒ Object
Returns the value of attribute tracking.
30 31 32 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 30 def tracking @tracking end |
#type ⇒ Object
Direction of the shipment relative to the organization.
28 29 30 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 28 def type @type end |
#updated_at ⇒ Object
Timestamp when the shipment was last updated.
41 42 43 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 41 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 72 def self.attribute_map { :'id' => :'id', :'reference' => :'reference', :'status' => :'status', :'type' => :'type', :'tracking' => :'tracking', :'carrier_settings' => :'carrierSettings', :'service_point_id' => :'servicePointId', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'shipping_rule_id' => :'shippingRuleId', :'documents' => :'documents' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 358 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 122 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 116 def self.openapi_nullable Set.new([ :'tracking', :'service_point_id', :'shipping_rule_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 99 def self.openapi_types { :'id' => :'String', :'reference' => :'String', :'status' => :'String', :'type' => :'String', :'tracking' => :'CreateShipment201ResponseTracking', :'carrier_settings' => :'ListShipments200ResponseDataInnerCarrierSettings', :'service_point_id' => :'String', :'created_at' => :'String', :'updated_at' => :'String', :'shipping_rule_id' => :'String', :'documents' => :'Array<CreateShipment201ResponseDocumentsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 327 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && reference == o.reference && status == o.status && type == o.type && tracking == o.tracking && carrier_settings == o.carrier_settings && service_point_id == o.service_point_id && created_at == o.created_at && updated_at == o.updated_at && shipping_rule_id == o.shipping_rule_id && documents == o.documents end |
#eql?(o) ⇒ Boolean
345 346 347 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 345 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 351 def hash [id, reference, status, type, tracking, carrier_settings, service_point_id, created_at, updated_at, shipping_rule_id, documents].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 203 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @reference.nil? invalid_properties.push('invalid value for "reference", reference cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @carrier_settings.nil? invalid_properties.push('invalid value for "carrier_settings", carrier_settings cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 380 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zippendo/models/get_order200_response_shipments_inner.rb', line 239 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @reference.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["draft", "pending", "processing", "dispatched", "partly_dispatched", "error", "cancelled", "on_hold"]) return false unless status_validator.valid?(@status) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["outbound", "inbound"]) return false unless type_validator.valid?(@type) return false if @carrier_settings.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |