Class: Zippendo::ListAvailableCarriers200ResponseInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::ListAvailableCarriers200ResponseInner
- Defined in:
- lib/zippendo/models/list_available_carriers200_response_inner.rb
Instance Attribute Summary collapse
-
#brand_color ⇒ Object
Carrier brand color (hex).
-
#deprecated ⇒ Object
Whether this integration is deprecated (still works, but discouraged).
-
#deprecation_message ⇒ Object
Guidance shown alongside the deprecated tag (e.g. what to migrate to).
-
#description ⇒ Object
Short description of the carrier.
-
#group ⇒ Object
Carrier group or family name.
-
#learn_more_url ⇒ Object
URL with more information about the carrier.
-
#logo ⇒ Object
URL to the carrier logo image.
-
#name ⇒ Object
Display name of the carrier.
-
#optional_fields ⇒ Object
Optional configuration fields for the carrier.
-
#required_fields ⇒ Object
Configuration fields that must be provided to connect the carrier.
-
#slug ⇒ Object
Unique carrier slug identifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListAvailableCarriers200ResponseInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListAvailableCarriers200ResponseInner
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListAvailableCarriers200ResponseInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListAvailableCarriers200ResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'logo') self.logo = attributes[:'logo'] end if attributes.key?(:'brand_color') self.brand_color = attributes[:'brand_color'] end if attributes.key?(:'learn_more_url') self.learn_more_url = attributes[:'learn_more_url'] end if attributes.key?(:'required_fields') if (value = attributes[:'required_fields']).is_a?(Array) self.required_fields = value end end if attributes.key?(:'optional_fields') if (value = attributes[:'optional_fields']).is_a?(Array) self.optional_fields = value end end if attributes.key?(:'deprecated') self.deprecated = attributes[:'deprecated'] end if attributes.key?(:'deprecation_message') self. = attributes[:'deprecation_message'] end end |
Instance Attribute Details
#brand_color ⇒ Object
Carrier brand color (hex)
34 35 36 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 34 def brand_color @brand_color end |
#deprecated ⇒ Object
Whether this integration is deprecated (still works, but discouraged)
46 47 48 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 46 def deprecated @deprecated end |
#deprecation_message ⇒ Object
Guidance shown alongside the deprecated tag (e.g. what to migrate to)
49 50 51 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 49 def @deprecation_message end |
#description ⇒ Object
Short description of the carrier
28 29 30 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 28 def description @description end |
#group ⇒ Object
Carrier group or family name
25 26 27 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 25 def group @group end |
#learn_more_url ⇒ Object
URL with more information about the carrier
37 38 39 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 37 def learn_more_url @learn_more_url end |
#logo ⇒ Object
URL to the carrier logo image
31 32 33 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 31 def logo @logo end |
#name ⇒ Object
Display name of the carrier
19 20 21 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 19 def name @name end |
#optional_fields ⇒ Object
Optional configuration fields for the carrier
43 44 45 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 43 def optional_fields @optional_fields end |
#required_fields ⇒ Object
Configuration fields that must be provided to connect the carrier
40 41 42 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 40 def required_fields @required_fields end |
#slug ⇒ Object
Unique carrier slug identifier
22 23 24 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 22 def slug @slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 52 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'group' => :'group', :'description' => :'description', :'logo' => :'logo', :'brand_color' => :'brandColor', :'learn_more_url' => :'learnMoreUrl', :'required_fields' => :'requiredFields', :'optional_fields' => :'optionalFields', :'deprecated' => :'deprecated', :'deprecation_message' => :'deprecationMessage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 248 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 79 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'group' => :'String', :'description' => :'String', :'logo' => :'String', :'brand_color' => :'String', :'learn_more_url' => :'String', :'required_fields' => :'Array<ListAvailableCarriers200ResponseInnerRequiredFieldsInner>', :'optional_fields' => :'Array<ListAvailableCarriers200ResponseInnerRequiredFieldsInner>', :'deprecated' => :'Boolean', :'deprecation_message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 217 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && group == o.group && description == o.description && logo == o.logo && brand_color == o.brand_color && learn_more_url == o.learn_more_url && required_fields == o.required_fields && optional_fields == o.optional_fields && deprecated == o.deprecated && == o. end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 241 def hash [name, slug, group, description, logo, brand_color, learn_more_url, required_fields, optional_fields, deprecated, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 |
# File 'lib/zippendo/models/list_available_carriers200_response_inner.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @slug.nil? true end |