Class: Zippendo::ListOrders200ResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::ListOrders200ResponseDataInner
- Defined in:
- lib/zippendo/models/list_orders200_response_data_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Creation timestamp (ISO 8601).
-
#currency ⇒ Object
ISO 4217 currency code.
-
#customer_email ⇒ Object
Customer email address.
-
#customer_name ⇒ Object
Customer full name.
-
#id ⇒ Object
Unique order ID.
-
#order_channel ⇒ Object
Returns the value of attribute order_channel.
-
#order_number ⇒ Object
Human-readable order number.
-
#shipment_count ⇒ Object
Number of shipments created for the order.
-
#status ⇒ Object
Order fulfilment status derived from its shipments.
-
#subtotal_amount ⇒ Object
Order subtotal before shipping and tax.
-
#total_amount ⇒ Object
Order grand total.
-
#updated_at ⇒ Object
Last update timestamp (ISO 8601).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListOrders200ResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListOrders200ResponseDataInner
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::ListOrders200ResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::ListOrders200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'order_number') self.order_number = attributes[:'order_number'] else self.order_number = nil end if attributes.key?(:'customer_name') self.customer_name = attributes[:'customer_name'] end if attributes.key?(:'customer_email') self.customer_email = attributes[:'customer_email'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'subtotal_amount') self.subtotal_amount = attributes[:'subtotal_amount'] end if attributes.key?(:'total_amount') self.total_amount = attributes[:'total_amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'shipment_count') self.shipment_count = attributes[:'shipment_count'] else self.shipment_count = nil end if attributes.key?(:'order_channel') self.order_channel = attributes[:'order_channel'] else self.order_channel = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Creation timestamp (ISO 8601).
48 49 50 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 48 def created_at @created_at end |
#currency ⇒ Object
ISO 4217 currency code.
40 41 42 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 40 def currency @currency end |
#customer_email ⇒ Object
Customer email address.
28 29 30 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 28 def customer_email @customer_email end |
#customer_name ⇒ Object
Customer full name.
25 26 27 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 25 def customer_name @customer_name end |
#id ⇒ Object
Unique order ID.
19 20 21 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 19 def id @id end |
#order_channel ⇒ Object
Returns the value of attribute order_channel.
45 46 47 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 45 def order_channel @order_channel end |
#order_number ⇒ Object
Human-readable order number.
22 23 24 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 22 def order_number @order_number end |
#shipment_count ⇒ Object
Number of shipments created for the order.
43 44 45 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 43 def shipment_count @shipment_count end |
#status ⇒ Object
Order fulfilment status derived from its shipments.
31 32 33 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 31 def status @status end |
#subtotal_amount ⇒ Object
Order subtotal before shipping and tax.
34 35 36 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 34 def subtotal_amount @subtotal_amount end |
#total_amount ⇒ Object
Order grand total.
37 38 39 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 37 def total_amount @total_amount end |
#updated_at ⇒ Object
Last update timestamp (ISO 8601).
51 52 53 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 51 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
94 95 96 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 94 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 99 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 76 def self.attribute_map { :'id' => :'id', :'order_number' => :'orderNumber', :'customer_name' => :'customerName', :'customer_email' => :'customerEmail', :'status' => :'status', :'subtotal_amount' => :'subtotalAmount', :'total_amount' => :'totalAmount', :'currency' => :'currency', :'shipment_count' => :'shipmentCount', :'order_channel' => :'orderChannel', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 385 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 126 127 128 129 130 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 122 def self.openapi_nullable Set.new([ :'customer_name', :'customer_email', :'subtotal_amount', :'total_amount', :'currency', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 104 def self.openapi_types { :'id' => :'String', :'order_number' => :'String', :'customer_name' => :'String', :'customer_email' => :'String', :'status' => :'String', :'subtotal_amount' => :'Float', :'total_amount' => :'Float', :'currency' => :'String', :'shipment_count' => :'Integer', :'order_channel' => :'ListOrders200ResponseDataInnerOrderChannel', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && order_number == o.order_number && customer_name == o.customer_name && customer_email == o.customer_email && status == o.status && subtotal_amount == o.subtotal_amount && total_amount == o.total_amount && currency == o.currency && shipment_count == o.shipment_count && order_channel == o.order_channel && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
372 373 374 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 372 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
378 379 380 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 378 def hash [id, order_number, customer_name, customer_email, status, subtotal_amount, total_amount, currency, shipment_count, order_channel, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 213 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @order_number.nil? invalid_properties.push('invalid value for "order_number", order_number cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @shipment_count.nil? invalid_properties.push('invalid value for "shipment_count", shipment_count cannot be nil.') end if @shipment_count > 9007199254740991 invalid_properties.push('invalid value for "shipment_count", must be smaller than or equal to 9007199254740991.') end if @shipment_count < 0 invalid_properties.push('invalid value for "shipment_count", must be greater than or equal to 0.') end if @order_channel.nil? invalid_properties.push('invalid value for "order_channel", order_channel cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 407 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/zippendo/models/list_orders200_response_data_inner.rb', line 257 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @order_number.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["pending", "processing", "partially_fulfilled", "fulfilled", "error", "cancelled"]) return false unless status_validator.valid?(@status) return false if @shipment_count.nil? return false if @shipment_count > 9007199254740991 return false if @shipment_count < 0 return false if @order_channel.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |