Class: Zippendo::OrgsApi
- Inherits:
-
Object
- Object
- Zippendo::OrgsApi
- Defined in:
- lib/zippendo/api/orgs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_org_logo(org_id, opts = {}) ⇒ GetOrgBranding200Response
Delete org logo Removes the org logo.
-
#delete_org_logo_with_http_info(org_id, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Delete org logo Removes the org logo.
-
#get_org(id, opts = {}) ⇒ GetOrg200Response
Get org Returns a specific organization by ID, including its member count.
-
#get_org_branding(org_id, opts = {}) ⇒ GetOrgBranding200Response
Get org branding Returns the org's brand colors and an authenticated URL to download the logo.
-
#get_org_branding_with_http_info(org_id, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Get org branding Returns the org's brand colors and an authenticated URL to download the logo.
-
#get_org_logo(org_id, opts = {}) ⇒ File
Download org logo Returns the org logo image bytes with the stored content type.
-
#get_org_logo_with_http_info(org_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Download org logo Returns the org logo image bytes with the stored content type.
-
#get_org_with_http_info(id, opts = {}) ⇒ Array<(GetOrg200Response, Integer, Hash)>
Get org Returns a specific organization by ID, including its member count.
-
#initialize(api_client = ApiClient.default) ⇒ OrgsApi
constructor
A new instance of OrgsApi.
-
#update_org(id, update_org_request, opts = {}) ⇒ UpdateOrg200Response
Update org Updates an existing organization's profile, billing, and customs settings.
-
#update_org_branding(org_id, update_org_branding_request, opts = {}) ⇒ GetOrgBranding200Response
Update org branding Sets the org brand colors.
-
#update_org_branding_with_http_info(org_id, update_org_branding_request, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Update org branding Sets the org brand colors.
-
#update_org_with_http_info(id, update_org_request, opts = {}) ⇒ Array<(UpdateOrg200Response, Integer, Hash)>
Update org Updates an existing organization's profile, billing, and customs settings.
-
#upload_org_logo(org_id, file, opts = {}) ⇒ GetOrgBranding200Response
Upload org logo Uploads the org logo as multipart/form-data.
-
#upload_org_logo_with_http_info(org_id, file, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Upload org logo Uploads the org logo as multipart/form-data.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zippendo/api/orgs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_org_logo(org_id, opts = {}) ⇒ GetOrgBranding200Response
Delete org logo Removes the org logo. Requires the customBranding entitlement.
27 28 29 30 |
# File 'lib/zippendo/api/orgs_api.rb', line 27 def delete_org_logo(org_id, opts = {}) data, _status_code, _headers = delete_org_logo_with_http_info(org_id, opts) data end |
#delete_org_logo_with_http_info(org_id, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Delete org logo Removes the org logo. Requires the customBranding entitlement.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zippendo/api/orgs_api.rb', line 37 def delete_org_logo_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.delete_org_logo ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrgsApi.delete_org_logo" end # resource path local_var_path = '/orgs/{orgId}/branding/logo'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrgBranding200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.delete_org_logo", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#delete_org_logo\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_org(id, opts = {}) ⇒ GetOrg200Response
Get org Returns a specific organization by ID, including its member count.
90 91 92 93 |
# File 'lib/zippendo/api/orgs_api.rb', line 90 def get_org(id, opts = {}) data, _status_code, _headers = get_org_with_http_info(id, opts) data end |
#get_org_branding(org_id, opts = {}) ⇒ GetOrgBranding200Response
Get org branding Returns the org's brand colors and an authenticated URL to download the logo.
153 154 155 156 |
# File 'lib/zippendo/api/orgs_api.rb', line 153 def get_org_branding(org_id, opts = {}) data, _status_code, _headers = get_org_branding_with_http_info(org_id, opts) data end |
#get_org_branding_with_http_info(org_id, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Get org branding Returns the org's brand colors and an authenticated URL to download the logo.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zippendo/api/orgs_api.rb', line 163 def get_org_branding_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.get_org_branding ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrgsApi.get_org_branding" end # resource path local_var_path = '/orgs/{orgId}/branding'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrgBranding200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.get_org_branding", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#get_org_branding\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_org_logo(org_id, opts = {}) ⇒ File
Download org logo Returns the org logo image bytes with the stored content type.
216 217 218 219 |
# File 'lib/zippendo/api/orgs_api.rb', line 216 def get_org_logo(org_id, opts = {}) data, _status_code, _headers = get_org_logo_with_http_info(org_id, opts) data end |
#get_org_logo_with_http_info(org_id, opts = {}) ⇒ Array<(File, Integer, Hash)>
Download org logo Returns the org logo image bytes with the stored content type.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/zippendo/api/orgs_api.rb', line 226 def get_org_logo_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.get_org_logo ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrgsApi.get_org_logo" end # resource path local_var_path = '/orgs/{orgId}/branding/logo'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['image/png', 'image/jpeg', 'image/webp']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'File' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.get_org_logo", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#get_org_logo\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_org_with_http_info(id, opts = {}) ⇒ Array<(GetOrg200Response, Integer, Hash)>
Get org Returns a specific organization by ID, including its member count.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zippendo/api/orgs_api.rb', line 100 def get_org_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.get_org ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrgsApi.get_org" end # resource path local_var_path = '/orgs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrg200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.get_org", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#get_org\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_org(id, update_org_request, opts = {}) ⇒ UpdateOrg200Response
Update org Updates an existing organization's profile, billing, and customs settings.
280 281 282 283 |
# File 'lib/zippendo/api/orgs_api.rb', line 280 def update_org(id, update_org_request, opts = {}) data, _status_code, _headers = update_org_with_http_info(id, update_org_request, opts) data end |
#update_org_branding(org_id, update_org_branding_request, opts = {}) ⇒ GetOrgBranding200Response
Update org branding Sets the org brand colors. Requires the customBranding entitlement.
354 355 356 357 |
# File 'lib/zippendo/api/orgs_api.rb', line 354 def update_org_branding(org_id, update_org_branding_request, opts = {}) data, _status_code, _headers = update_org_branding_with_http_info(org_id, update_org_branding_request, opts) data end |
#update_org_branding_with_http_info(org_id, update_org_branding_request, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Update org branding Sets the org brand colors. Requires the customBranding entitlement.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/zippendo/api/orgs_api.rb', line 365 def update_org_branding_with_http_info(org_id, update_org_branding_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.update_org_branding ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrgsApi.update_org_branding" end # verify the required parameter 'update_org_branding_request' is set if @api_client.config.client_side_validation && update_org_branding_request.nil? fail ArgumentError, "Missing the required parameter 'update_org_branding_request' when calling OrgsApi.update_org_branding" end # resource path local_var_path = '/orgs/{orgId}/branding'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_org_branding_request) # return_type return_type = opts[:debug_return_type] || 'GetOrgBranding200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.update_org_branding", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#update_org_branding\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_org_with_http_info(id, update_org_request, opts = {}) ⇒ Array<(UpdateOrg200Response, Integer, Hash)>
Update org Updates an existing organization's profile, billing, and customs settings.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/zippendo/api/orgs_api.rb', line 291 def update_org_with_http_info(id, update_org_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.update_org ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrgsApi.update_org" end # verify the required parameter 'update_org_request' is set if @api_client.config.client_side_validation && update_org_request.nil? fail ArgumentError, "Missing the required parameter 'update_org_request' when calling OrgsApi.update_org" end # resource path local_var_path = '/orgs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_org_request) # return_type return_type = opts[:debug_return_type] || 'UpdateOrg200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.update_org", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#update_org\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload_org_logo(org_id, file, opts = {}) ⇒ GetOrgBranding200Response
Upload org logo Uploads the org logo as multipart/form-data. Accepts PNG, JPG, or WEBP up to 5MB and 4096×4096px; the image is re-encoded and stored. Requires the customBranding entitlement.
428 429 430 431 |
# File 'lib/zippendo/api/orgs_api.rb', line 428 def upload_org_logo(org_id, file, opts = {}) data, _status_code, _headers = upload_org_logo_with_http_info(org_id, file, opts) data end |
#upload_org_logo_with_http_info(org_id, file, opts = {}) ⇒ Array<(GetOrgBranding200Response, Integer, Hash)>
Upload org logo Uploads the org logo as multipart/form-data. Accepts PNG, JPG, or WEBP up to 5MB and 4096×4096px; the image is re-encoded and stored. Requires the customBranding entitlement.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/zippendo/api/orgs_api.rb', line 439 def upload_org_logo_with_http_info(org_id, file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrgsApi.upload_org_logo ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling OrgsApi.upload_org_logo" end # verify the required parameter 'file' is set if @api_client.config.client_side_validation && file.nil? fail ArgumentError, "Missing the required parameter 'file' when calling OrgsApi.upload_org_logo" end # resource path local_var_path = '/orgs/{orgId}/branding/logo'.sub('{orgId}', CGI.escape(org_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['file'] = file # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrgBranding200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrgsApi.upload_org_logo", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrgsApi#upload_org_logo\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |