Class: Zippendo::UpdateOrgRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::UpdateOrgRequest
- Defined in:
- lib/zippendo/models/update_org_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address_line1 ⇒ Object
Address line 1.
-
#address_line2 ⇒ Object
Address line 2.
-
#billing_email ⇒ Object
Billing email for invoices.
-
#city ⇒ Object
City.
-
#company_name ⇒ Object
Legal company name.
-
#country ⇒ Object
Country (ISO 3166-1 alpha-2 code).
-
#currency ⇒ Object
Billing currency (ISO 4217 code).
-
#customs ⇒ Object
Organization-wide customs identifiers (EORI, IOSS, VOEC, etc.); null clears all.
-
#description ⇒ Object
Organization description.
-
#name ⇒ Object
Organization name.
-
#overage_enabled ⇒ Object
Allow shipments beyond plan limit (overage charges apply).
-
#postal_code ⇒ Object
Postal code.
-
#slug ⇒ Object
Organization slug.
-
#vat_number ⇒ Object
Company VAT/tax ID for invoices.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrgRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrgRequest
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zippendo/models/update_org_request.rb', line 149 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrgRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrgRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'vat_number') self.vat_number = attributes[:'vat_number'] end if attributes.key?(:'overage_enabled') self.overage_enabled = attributes[:'overage_enabled'] end if attributes.key?(:'billing_email') self.billing_email = attributes[:'billing_email'] end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] end if attributes.key?(:'address_line1') self.address_line1 = attributes[:'address_line1'] end if attributes.key?(:'address_line2') self.address_line2 = attributes[:'address_line2'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'customs') if (value = attributes[:'customs']).is_a?(Hash) self.customs = value end end end |
Instance Attribute Details
#address_line1 ⇒ Object
Address line 1
43 44 45 |
# File 'lib/zippendo/models/update_org_request.rb', line 43 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
Address line 2
46 47 48 |
# File 'lib/zippendo/models/update_org_request.rb', line 46 def address_line2 @address_line2 end |
#billing_email ⇒ Object
Billing email for invoices
37 38 39 |
# File 'lib/zippendo/models/update_org_request.rb', line 37 def billing_email @billing_email end |
#city ⇒ Object
City
49 50 51 |
# File 'lib/zippendo/models/update_org_request.rb', line 49 def city @city end |
#company_name ⇒ Object
Legal company name
40 41 42 |
# File 'lib/zippendo/models/update_org_request.rb', line 40 def company_name @company_name end |
#country ⇒ Object
Country (ISO 3166-1 alpha-2 code)
55 56 57 |
# File 'lib/zippendo/models/update_org_request.rb', line 55 def country @country end |
#currency ⇒ Object
Billing currency (ISO 4217 code)
28 29 30 |
# File 'lib/zippendo/models/update_org_request.rb', line 28 def currency @currency end |
#customs ⇒ Object
Organization-wide customs identifiers (EORI, IOSS, VOEC, etc.); null clears all
58 59 60 |
# File 'lib/zippendo/models/update_org_request.rb', line 58 def customs @customs end |
#description ⇒ Object
Organization description
25 26 27 |
# File 'lib/zippendo/models/update_org_request.rb', line 25 def description @description end |
#name ⇒ Object
Organization name
19 20 21 |
# File 'lib/zippendo/models/update_org_request.rb', line 19 def name @name end |
#overage_enabled ⇒ Object
Allow shipments beyond plan limit (overage charges apply)
34 35 36 |
# File 'lib/zippendo/models/update_org_request.rb', line 34 def overage_enabled @overage_enabled end |
#postal_code ⇒ Object
Postal code
52 53 54 |
# File 'lib/zippendo/models/update_org_request.rb', line 52 def postal_code @postal_code end |
#slug ⇒ Object
Organization slug
22 23 24 |
# File 'lib/zippendo/models/update_org_request.rb', line 22 def slug @slug end |
#vat_number ⇒ Object
Company VAT/tax ID for invoices
31 32 33 |
# File 'lib/zippendo/models/update_org_request.rb', line 31 def vat_number @vat_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
103 104 105 |
# File 'lib/zippendo/models/update_org_request.rb', line 103 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
108 109 110 |
# File 'lib/zippendo/models/update_org_request.rb', line 108 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/zippendo/models/update_org_request.rb', line 83 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'description' => :'description', :'currency' => :'currency', :'vat_number' => :'vatNumber', :'overage_enabled' => :'overageEnabled', :'billing_email' => :'billingEmail', :'company_name' => :'companyName', :'address_line1' => :'addressLine1', :'address_line2' => :'addressLine2', :'city' => :'city', :'postal_code' => :'postalCode', :'country' => :'country', :'customs' => :'customs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/zippendo/models/update_org_request.rb', line 351 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/zippendo/models/update_org_request.rb', line 133 def self.openapi_nullable Set.new([ :'vat_number', :'billing_email', :'company_name', :'address_line1', :'address_line2', :'city', :'postal_code', :'country', :'customs' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zippendo/models/update_org_request.rb', line 113 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'description' => :'String', :'currency' => :'String', :'vat_number' => :'String', :'overage_enabled' => :'Boolean', :'billing_email' => :'String', :'company_name' => :'String', :'address_line1' => :'String', :'address_line2' => :'String', :'city' => :'String', :'postal_code' => :'String', :'country' => :'String', :'customs' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/zippendo/models/update_org_request.rb', line 317 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && description == o.description && currency == o.currency && vat_number == o.vat_number && overage_enabled == o.overage_enabled && billing_email == o.billing_email && company_name == o.company_name && address_line1 == o.address_line1 && address_line2 == o.address_line2 && city == o.city && postal_code == o.postal_code && country == o.country && customs == o.customs end |
#eql?(o) ⇒ Boolean
338 339 340 |
# File 'lib/zippendo/models/update_org_request.rb', line 338 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/zippendo/models/update_org_request.rb', line 344 def hash [name, slug, description, currency, vat_number, overage_enabled, billing_email, company_name, address_line1, address_line2, city, postal_code, country, customs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zippendo/models/update_org_request.rb', line 224 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@slug.nil? && @slug.to_s.length < 1 invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-z0-9-]+$/) if !@slug.nil? && @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) if !@billing_email.nil? && @billing_email !~ pattern invalid_properties.push("invalid value for \"billing_email\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/zippendo/models/update_org_request.rb', line 373 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/zippendo/models/update_org_request.rb', line 250 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@slug.nil? && @slug.to_s.length < 1 return false if !@slug.nil? && @slug !~ Regexp.new(/^[a-z0-9-]+$/) currency_validator = EnumAttributeValidator.new('String', ["DKK", "EUR", "USD", "GBP", "SEK", "NOK"]) return false unless currency_validator.valid?(@currency) return false if !@billing_email.nil? && @billing_email !~ Regexp.new(/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/) true end |