Class: Zippendo::UpdateOrgWebhookRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zippendo::UpdateOrgWebhookRequest
- Defined in:
- lib/zippendo/models/update_org_webhook_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#events ⇒ Object
Events to subscribe to.
-
#is_active ⇒ Object
Whether the webhook is active.
-
#name ⇒ Object
Human-readable webhook name.
-
#url ⇒ Object
Webhook endpoint URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOrgWebhookRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOrgWebhookRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zippendo::UpdateOrgWebhookRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zippendo::UpdateOrgWebhookRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#events ⇒ Object
Events to subscribe to
25 26 27 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 25 def events @events end |
#is_active ⇒ Object
Whether the webhook is active
28 29 30 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 28 def is_active @is_active end |
#name ⇒ Object
Human-readable webhook name
19 20 21 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 19 def name @name end |
#url ⇒ Object
Webhook endpoint URL
22 23 24 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 53 def self.attribute_map { :'name' => :'name', :'url' => :'url', :'events' => :'events', :'is_active' => :'isActive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 197 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 73 def self.openapi_types { :'name' => :'String', :'url' => :'String', :'events' => :'Array<String>', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && url == o.url && events == o.events && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
184 185 186 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 184 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 190 def hash [name, url, events, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@events.nil? && @events.length < 1 invalid_properties.push('invalid value for "events", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 |
# File 'lib/zippendo/models/update_org_webhook_request.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 100 return false if !@name.nil? && @name.to_s.length < 1 return false if !@events.nil? && @events.length < 1 true end |